"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.sms_ten_dlc_partner_campaign_brand import SMSTenDLCPartnerCampaignBrand  # noqa: E501

class TestSMSTenDLCPartnerCampaignBrand(unittest.TestCase):
    """SMSTenDLCPartnerCampaignBrand unit test stubs"""

    def setUp(self):
        self.model = SMSTenDLCPartnerCampaignBrand(
            phone="",
            email="",
        )
    
    def test_account_id(self):
        """Test SMSTenDLCPartnerCampaignBrand.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_brand_id(self):
        """Test SMSTenDLCPartnerCampaignBrand.brand_id"""
        self.model.brand_id = "TEST_STRING"
        assert self.model.get("brand_id") == "TEST_STRING"

    def test_first_name(self):
        """Test SMSTenDLCPartnerCampaignBrand.first_name"""
        self.model.first_name = "T" * 100
        assert self.model.get("first_name") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.first_name = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_last_name(self):
        """Test SMSTenDLCPartnerCampaignBrand.last_name"""
        self.model.last_name = "T" * 100
        assert self.model.get("last_name") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.last_name = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_display_name(self):
        """Test SMSTenDLCPartnerCampaignBrand.display_name"""
        self.model.display_name = "T" * 255
        assert self.model.get("display_name") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.display_name = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_company_name(self):
        """Test SMSTenDLCPartnerCampaignBrand.company_name"""
        self.model.company_name = "T" * 255
        assert self.model.get("company_name") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.company_name = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_phone(self):
        """Test SMSTenDLCPartnerCampaignBrand.phone"""
        self.model.phone = "T" * 20
        assert self.model.get("phone") == "T" * 20
        
        with pytest.raises(Exception) as info:
            self.model.phone = "T" * (20 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_email(self):
        """Test SMSTenDLCPartnerCampaignBrand.email"""
        self.model.email = "T" * 100
        assert self.model.get("email") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.email = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_website(self):
        """Test SMSTenDLCPartnerCampaignBrand.website"""
        self.model.website = "T" * 100
        assert self.model.get("website") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.website = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_optional_attributes(self):
        """Test SMSTenDLCPartnerCampaignBrand.optional_attributes"""
        self.model.optional_attributes = {}
        assert self.model.get("optional_attributes") == {}

    def test_evp_vetting_score(self):
        """Test SMSTenDLCPartnerCampaignBrand.evp_vetting_score"""
        self.model.evp_vetting_score = 1
        assert self.model.get("evp_vetting_score") == 1

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.account_status import AccountStatus  # noqa: E501

class TestAccountStatus(unittest.TestCase):
    """AccountStatus unit test stubs"""

    
    def test_CLOSED_should_serialize_to_enum(self):
        expected = AccountStatus.CLOSED
        calculated = AccountStatus['CLOSED']
        assert expected == calculated

    def test_CLOSED_should_deserialize_to_string(self):
        test = AccountStatus.CLOSED
        expected = "closed"
        calculated = test.value
        assert expected == calculated

    def test_SUSPENDED_should_serialize_to_enum(self):
        expected = AccountStatus.SUSPENDED
        calculated = AccountStatus['SUSPENDED']
        assert expected == calculated

    def test_SUSPENDED_should_deserialize_to_string(self):
        test = AccountStatus.SUSPENDED
        expected = "suspended"
        calculated = test.value
        assert expected == calculated

    def test_ACTIVE_should_serialize_to_enum(self):
        expected = AccountStatus.ACTIVE
        calculated = AccountStatus['ACTIVE']
        assert expected == calculated

    def test_ACTIVE_should_deserialize_to_string(self):
        test = AccountStatus.ACTIVE
        expected = "active"
        calculated = test.value
        assert expected == calculated

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.grammar_file_built_in import GrammarFileBuiltIn  # noqa: E501

class TestGrammarFileBuiltIn(unittest.TestCase):
    """GrammarFileBuiltIn unit test stubs"""

    
    def test_ALPHNUM6_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.ALPHNUM6
        calculated = GrammarFileBuiltIn['ALPHNUM6']
        assert expected == calculated

    def test_ALPHNUM6_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.ALPHNUM6
        expected = "ALPHNUM6"
        calculated = test.value
        assert expected == calculated

    def test_ANY_DIG_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.ANY_DIG
        calculated = GrammarFileBuiltIn['ANY_DIG']
        assert expected == calculated

    def test_ANY_DIG_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.ANY_DIG
        expected = "ANY_DIG"
        calculated = test.value
        assert expected == calculated

    def test_DIG1_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG1
        calculated = GrammarFileBuiltIn['DIG1']
        assert expected == calculated

    def test_DIG1_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG1
        expected = "DIG1"
        calculated = test.value
        assert expected == calculated

    def test_DIG2_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG2
        calculated = GrammarFileBuiltIn['DIG2']
        assert expected == calculated

    def test_DIG2_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG2
        expected = "DIG2"
        calculated = test.value
        assert expected == calculated

    def test_DIG3_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG3
        calculated = GrammarFileBuiltIn['DIG3']
        assert expected == calculated

    def test_DIG3_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG3
        expected = "DIG3"
        calculated = test.value
        assert expected == calculated

    def test_DIG4_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG4
        calculated = GrammarFileBuiltIn['DIG4']
        assert expected == calculated

    def test_DIG4_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG4
        expected = "DIG4"
        calculated = test.value
        assert expected == calculated

    def test_DIG5_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG5
        calculated = GrammarFileBuiltIn['DIG5']
        assert expected == calculated

    def test_DIG5_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG5
        expected = "DIG5"
        calculated = test.value
        assert expected == calculated

    def test_DIG6_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG6
        calculated = GrammarFileBuiltIn['DIG6']
        assert expected == calculated

    def test_DIG6_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG6
        expected = "DIG6"
        calculated = test.value
        assert expected == calculated

    def test_DIG7_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG7
        calculated = GrammarFileBuiltIn['DIG7']
        assert expected == calculated

    def test_DIG7_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG7
        expected = "DIG7"
        calculated = test.value
        assert expected == calculated

    def test_DIG8_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG8
        calculated = GrammarFileBuiltIn['DIG8']
        assert expected == calculated

    def test_DIG8_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG8
        expected = "DIG8"
        calculated = test.value
        assert expected == calculated

    def test_DIG9_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG9
        calculated = GrammarFileBuiltIn['DIG9']
        assert expected == calculated

    def test_DIG9_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG9
        expected = "DIG9"
        calculated = test.value
        assert expected == calculated

    def test_DIG10_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG10
        calculated = GrammarFileBuiltIn['DIG10']
        assert expected == calculated

    def test_DIG10_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG10
        expected = "DIG10"
        calculated = test.value
        assert expected == calculated

    def test_DIG11_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.DIG11
        calculated = GrammarFileBuiltIn['DIG11']
        assert expected == calculated

    def test_DIG11_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.DIG11
        expected = "DIG11"
        calculated = test.value
        assert expected == calculated

    def test_UP_TO_20_DIGIT_SEQUENCE_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.UP_TO_20_DIGIT_SEQUENCE
        calculated = GrammarFileBuiltIn['UP_TO_20_DIGIT_SEQUENCE']
        assert expected == calculated

    def test_UP_TO_20_DIGIT_SEQUENCE_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.UP_TO_20_DIGIT_SEQUENCE
        expected = "UP_TO_20_DIGIT_SEQUENCE"
        calculated = test.value
        assert expected == calculated

    def test_VERSAY_YESNO_should_serialize_to_enum(self):
        expected = GrammarFileBuiltIn.VERSAY_YESNO
        calculated = GrammarFileBuiltIn['VERSAY_YESNO']
        assert expected == calculated

    def test_VERSAY_YESNO_should_deserialize_to_string(self):
        test = GrammarFileBuiltIn.VERSAY_YESNO
        expected = "VERSAY_YESNO"
        calculated = test.value
        assert expected == calculated

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.pagination_model import PaginationModel
from freeclimb.model.queue_list_all_of import QueueListAllOf
from freeclimb.model.queue_result import QueueResult
globals()['PaginationModel'] = PaginationModel
globals()['QueueListAllOf'] = QueueListAllOf
globals()['QueueResult'] = QueueResult

from freeclimb.model.queue_list import QueueList  # noqa: E501

class TestQueueList(unittest.TestCase):
    """QueueList unit test stubs"""

    def setUp(self):
        self.model = QueueList(
        )
    
    def test_total(self):
        """Test QueueList.total"""
        self.model.total = 1
        assert self.model.get("total") == 1

    def test_start(self):
        """Test QueueList.start"""
        self.model.start = 1
        assert self.model.get("start") == 1

    def test_end(self):
        """Test QueueList.end"""
        self.model.end = 1
        assert self.model.get("end") == 1

    def test_page(self):
        """Test QueueList.page"""
        self.model.page = 1
        assert self.model.get("page") == 1

    def test_num_pages(self):
        """Test QueueList.num_pages"""
        self.model.num_pages = 1
        assert self.model.get("num_pages") == 1

    def test_page_size(self):
        """Test QueueList.page_size"""
        self.model.page_size = 1
        assert self.model.get("page_size") == 1

    def test_next_page_uri(self):
        """Test QueueList.next_page_uri"""
        self.model.next_page_uri = "TEST_STRING"
        assert self.model.get("next_page_uri") == "TEST_STRING"

    def test_queues(self):
        """Test QueueList.queues"""
        testList = []
        self.model.queues = testList
        assert self.model.get("queues") == testList

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.pagination_model import PaginationModel
from freeclimb.model.sms_ten_dlc_brand import SMSTenDLCBrand
from freeclimb.model.sms_ten_dlc_brands_list_result_all_of import SMSTenDLCBrandsListResultAllOf
globals()['PaginationModel'] = PaginationModel
globals()['SMSTenDLCBrand'] = SMSTenDLCBrand
globals()['SMSTenDLCBrandsListResultAllOf'] = SMSTenDLCBrandsListResultAllOf

from freeclimb.model.sms_ten_dlc_brands_list_result import SMSTenDLCBrandsListResult  # noqa: E501

class TestSMSTenDLCBrandsListResult(unittest.TestCase):
    """SMSTenDLCBrandsListResult unit test stubs"""

    def setUp(self):
        self.model = SMSTenDLCBrandsListResult(
        )
    
    def test_total(self):
        """Test SMSTenDLCBrandsListResult.total"""
        self.model.total = 1
        assert self.model.get("total") == 1

    def test_start(self):
        """Test SMSTenDLCBrandsListResult.start"""
        self.model.start = 1
        assert self.model.get("start") == 1

    def test_end(self):
        """Test SMSTenDLCBrandsListResult.end"""
        self.model.end = 1
        assert self.model.get("end") == 1

    def test_page(self):
        """Test SMSTenDLCBrandsListResult.page"""
        self.model.page = 1
        assert self.model.get("page") == 1

    def test_num_pages(self):
        """Test SMSTenDLCBrandsListResult.num_pages"""
        self.model.num_pages = 1
        assert self.model.get("num_pages") == 1

    def test_page_size(self):
        """Test SMSTenDLCBrandsListResult.page_size"""
        self.model.page_size = 1
        assert self.model.get("page_size") == 1

    def test_next_page_uri(self):
        """Test SMSTenDLCBrandsListResult.next_page_uri"""
        self.model.next_page_uri = "TEST_STRING"
        assert self.model.get("next_page_uri") == "TEST_STRING"

    def test_brands(self):
        """Test SMSTenDLCBrandsListResult.brands"""
        testList = []
        self.model.brands = testList
        assert self.model.get("brands") == testList

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.conference_result_all_of import ConferenceResultAllOf
from freeclimb.model.conference_status import ConferenceStatus
from freeclimb.model.mutable_resource_model import MutableResourceModel
from freeclimb.model.play_beep import PlayBeep
globals()['ConferenceResultAllOf'] = ConferenceResultAllOf
globals()['ConferenceStatus'] = ConferenceStatus
globals()['MutableResourceModel'] = MutableResourceModel
globals()['PlayBeep'] = PlayBeep

from freeclimb.model.conference_result import ConferenceResult  # noqa: E501

class TestConferenceResult(unittest.TestCase):
    """ConferenceResult unit test stubs"""

    def setUp(self):
        self.model = ConferenceResult(
        )
    
    def test_uri(self):
        """Test ConferenceResult.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test ConferenceResult.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test ConferenceResult.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test ConferenceResult.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test_conference_id(self):
        """Test ConferenceResult.conference_id"""
        self.model.conference_id = "TEST_STRING"
        assert self.model.get("conference_id") == "TEST_STRING"

    def test_account_id(self):
        """Test ConferenceResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_alias(self):
        """Test ConferenceResult.alias"""
        self.model.alias = "TEST_STRING"
        assert self.model.get("alias") == "TEST_STRING"

    def test_play_beep(self):
        """Test ConferenceResult.play_beep"""
        self.model.play_beep = PlayBeep.ALWAYS
        assert self.model.get("play_beep") == PlayBeep.ALWAYS
        self.model.play_beep = PlayBeep.NEVER
        assert self.model.get("play_beep") == PlayBeep.NEVER
        self.model.play_beep = PlayBeep.ENTRY_ONLY
        assert self.model.get("play_beep") == PlayBeep.ENTRY_ONLY
        self.model.play_beep = PlayBeep.EXIT_ONLY
        assert self.model.get("play_beep") == PlayBeep.EXIT_ONLY

    def test_record(self):
        """Test ConferenceResult.record"""
        self.model.record = False
        assert self.model.get("record") == False

    def test_status(self):
        """Test ConferenceResult.status"""
        self.model.status = ConferenceStatus.EMPTY
        assert self.model.get("status") == ConferenceStatus.EMPTY
        self.model.status = ConferenceStatus.POPULATED
        assert self.model.get("status") == ConferenceStatus.POPULATED
        self.model.status = ConferenceStatus.IN_PROGRESS
        assert self.model.get("status") == ConferenceStatus.IN_PROGRESS
        self.model.status = ConferenceStatus.TERMINATED
        assert self.model.get("status") == ConferenceStatus.TERMINATED

    def test_wait_url(self):
        """Test ConferenceResult.wait_url"""
        self.model.wait_url = "TEST_STRING"
        assert self.model.get("wait_url") == "TEST_STRING"

    def test_action_url(self):
        """Test ConferenceResult.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.get("action_url") == "TEST_STRING"

    def test_status_callback_url(self):
        """Test ConferenceResult.status_callback_url"""
        self.model.status_callback_url = "TEST_STRING"
        assert self.model.get("status_callback_url") == "TEST_STRING"

    def test_subresource_uris(self):
        """Test ConferenceResult.subresource_uris"""
        testObject = {}
        self.model.subresource_uris = testObject
        assert self.model.get("subresource_uris") == testObject

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.transcribe_utterance_record import TranscribeUtteranceRecord
globals()['TranscribeUtteranceRecord'] = TranscribeUtteranceRecord

from freeclimb.model.transcribe_utterance import TranscribeUtterance  # noqa: E501

class TestTranscribeUtterance(unittest.TestCase):
    """TranscribeUtterance unit test stubs"""

    def setUp(self):
        self.model = TranscribeUtterance(action_url="TEST_URL")
    
    def test_action_url(self):
        """Test TranscribeUtterance.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.get("action_url") == "TEST_STRING"
        
         

     
    def test_play_beep(self):
        """Test TranscribeUtterance.play_beep"""
        self.model.play_beep = False
        assert self.model.get("play_beep") == False
        
         

     
    def test_record(self):
        """Test TranscribeUtterance.record"""
        self.model.record = TranscribeUtteranceRecord(save_recording=False, max_length_sec=1, rcrd_termination_silence_time_ms=1)
        assert isinstance(self.model.record, TranscribeUtteranceRecord)
         

     
    def test_privacy_for_logging(self):
        """Test TranscribeUtterance.privacy_for_logging"""
        self.model.privacy_for_logging = False
        assert self.model.get("privacy_for_logging") == False
        
         

     
    def test_privacy_for_recording(self):
        """Test TranscribeUtterance.privacy_for_recording"""
        self.model.privacy_for_recording = False
        assert self.model.get("privacy_for_recording") == False
        
         

     
    def test_prompts(self):
        """Test TranscribeUtterance.prompts"""
        testArray = []
        self.model.prompts = testArray
        assert self.model.get("prompts") == testArray
        
         

     

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.log_level import LogLevel
globals()['LogLevel'] = LogLevel

from freeclimb.model.log_result import LogResult  # noqa: E501

class TestLogResult(unittest.TestCase):
    """LogResult unit test stubs"""

    def setUp(self):
        self.model = LogResult(
        )
    
    def test_timestamp(self):
        """Test LogResult.timestamp"""
        self.model.timestamp = 1
        assert self.model.get("timestamp") == 1

    def test_level(self):
        """Test LogResult.level"""
        self.model.level = LogLevel.INFO
        assert self.model.get("level") == LogLevel.INFO
        self.model.level = LogLevel.WARNING
        assert self.model.get("level") == LogLevel.WARNING
        self.model.level = LogLevel.ERROR
        assert self.model.get("level") == LogLevel.ERROR

    def test_request_id(self):
        """Test LogResult.request_id"""
        self.model.request_id = "TEST_STRING"
        assert self.model.get("request_id") == "TEST_STRING"

    def test_account_id(self):
        """Test LogResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_call_id(self):
        """Test LogResult.call_id"""
        self.model.call_id = "TEST_STRING"
        assert self.model.get("call_id") == "TEST_STRING"

    def test_message(self):
        """Test LogResult.message"""
        self.model.message = "TEST_STRING"
        assert self.model.get("message") == "TEST_STRING"

    def test_metadata(self):
        """Test LogResult.metadata"""
        testObject = {}
        self.model.metadata = testObject
        assert self.model.get("metadata") == testObject

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.grammar_type import GrammarType
from freeclimb.model.percl_command import PerclCommand
globals()['GrammarType'] = GrammarType
globals()['PerclCommand'] = PerclCommand

from freeclimb.model.get_speech_all_of import GetSpeechAllOf  # noqa: E501

class TestGetSpeechAllOf(unittest.TestCase):
    """GetSpeechAllOf unit test stubs"""

    def setUp(self):
        self.model = GetSpeechAllOf(
            action_url="",
            grammar_file="",
        )
    
    def test_action_url(self):
        """Test GetSpeechAllOf.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.get("action_url") == "TEST_STRING"

    def test_grammar_type(self):
        """Test GetSpeechAllOf.grammar_type"""
        self.model.grammar_type = GrammarType.URL
        assert self.model.get("grammar_type") == GrammarType.URL
        self.model.grammar_type = GrammarType.BUILT_IN
        assert self.model.get("grammar_type") == GrammarType.BUILT_IN

    def test_grammar_file(self):
        """Test GetSpeechAllOf.grammar_file"""
        self.model.grammar_file = "TEST_STRING"
        assert self.model.get("grammar_file") == "TEST_STRING"

    def test_grammar_rule(self):
        """Test GetSpeechAllOf.grammar_rule"""
        self.model.grammar_rule = "TEST_STRING"
        assert self.model.get("grammar_rule") == "TEST_STRING"

    def test_play_beep(self):
        """Test GetSpeechAllOf.play_beep"""
        self.model.play_beep = False
        assert self.model.get("play_beep") == False

    def test_prompts(self):
        """Test GetSpeechAllOf.prompts"""
        testList = []
        self.model.prompts = testList
        assert self.model.get("prompts") == testList

    def test_no_input_timeout_ms(self):
        """Test GetSpeechAllOf.no_input_timeout_ms"""
        self.model.no_input_timeout_ms = 1
        assert self.model.get("no_input_timeout_ms") == 1

    def test_recognition_timeout_ms(self):
        """Test GetSpeechAllOf.recognition_timeout_ms"""
        self.model.recognition_timeout_ms = 1
        assert self.model.get("recognition_timeout_ms") == 1

    def test_confidence_threshold(self):
        """Test GetSpeechAllOf.confidence_threshold"""
        self.model.confidence_threshold = float(1) 
        assert self.model.get("confidence_threshold") == float(1)

    def test_sensitivity_level(self):
        """Test GetSpeechAllOf.sensitivity_level"""
        self.model.sensitivity_level = float(1) 
        assert self.model.get("sensitivity_level") == float(1)

    def test_speech_complete_timeout_ms(self):
        """Test GetSpeechAllOf.speech_complete_timeout_ms"""
        self.model.speech_complete_timeout_ms = 1
        assert self.model.get("speech_complete_timeout_ms") == 1

    def test_speech_incomplete_timeout_ms(self):
        """Test GetSpeechAllOf.speech_incomplete_timeout_ms"""
        self.model.speech_incomplete_timeout_ms = 1
        assert self.model.get("speech_incomplete_timeout_ms") == 1

    def test_privacy_mode(self):
        """Test GetSpeechAllOf.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.get("privacy_mode") == False

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.sms_ten_dlc_brand import SMSTenDLCBrand  # noqa: E501

class TestSMSTenDLCBrand(unittest.TestCase):
    """SMSTenDLCBrand unit test stubs"""

    def setUp(self):
        self.model = SMSTenDLCBrand(
            entity_type="PRIVATE_PROFIT",
            display_name="",
            phone="",
            country="",
            email="",
            brand_relationship="BASIC_ACCOUNT",
            vertical="",
            mock=True,
            identity_status="SELF_DECLARED",
        )
    
    def test_account_id(self):
        """Test SMSTenDLCBrand.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_entity_type(self):
        """Test SMSTenDLCBrand.entity_type"""
        self.model.entity_type = "PRIVATE_PROFIT"
        assert self.model.get("entity_type") == "PRIVATE_PROFIT"
        self.model.entity_type = "PUBLIC_PROFIT"
        assert self.model.get("entity_type") == "PUBLIC_PROFIT"
        self.model.entity_type = "NON_PROFIT"
        assert self.model.get("entity_type") == "NON_PROFIT"
        self.model.entity_type = "GOVERNMENT"
        assert self.model.get("entity_type") == "GOVERNMENT"
        self.model.entity_type = "SOLE_PROPRIETOR"
        assert self.model.get("entity_type") == "SOLE_PROPRIETOR"

    def test_entity_type_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.entity_type = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
    def test_csp_id(self):
        """Test SMSTenDLCBrand.csp_id"""
        self.model.csp_id = "TEST_STRING"
        assert self.model.get("csp_id") == "TEST_STRING"

    def test_brand_id(self):
        """Test SMSTenDLCBrand.brand_id"""
        self.model.brand_id = "TEST_STRING"
        assert self.model.get("brand_id") == "TEST_STRING"

    def test_first_name(self):
        """Test SMSTenDLCBrand.first_name"""
        self.model.first_name = "T" * 100
        assert self.model.get("first_name") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.first_name = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_last_name(self):
        """Test SMSTenDLCBrand.last_name"""
        self.model.last_name = "T" * 100
        assert self.model.get("last_name") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.last_name = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_display_name(self):
        """Test SMSTenDLCBrand.display_name"""
        self.model.display_name = "T" * 255
        assert self.model.get("display_name") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.display_name = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_company_name(self):
        """Test SMSTenDLCBrand.company_name"""
        self.model.company_name = "T" * 255
        assert self.model.get("company_name") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.company_name = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_ein(self):
        """Test SMSTenDLCBrand.ein"""
        self.model.ein = "T" * 21
        assert self.model.get("ein") == "T" * 21
        
        with pytest.raises(Exception) as info:
            self.model.ein = "T" * (21 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_ein_issuing_country(self):
        """Test SMSTenDLCBrand.ein_issuing_country"""
        self.model.ein_issuing_country = "T" * 2
        assert self.model.get("ein_issuing_country") == "T" * 2
        
        with pytest.raises(Exception) as info:
            self.model.ein_issuing_country = "T" * (2 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_phone(self):
        """Test SMSTenDLCBrand.phone"""
        self.model.phone = "T" * 20
        assert self.model.get("phone") == "T" * 20
        
        with pytest.raises(Exception) as info:
            self.model.phone = "T" * (20 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_street(self):
        """Test SMSTenDLCBrand.street"""
        self.model.street = "T" * 100
        assert self.model.get("street") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.street = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_city(self):
        """Test SMSTenDLCBrand.city"""
        self.model.city = "T" * 100
        assert self.model.get("city") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.city = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_state(self):
        """Test SMSTenDLCBrand.state"""
        self.model.state = "T" * 20
        assert self.model.get("state") == "T" * 20
        
        with pytest.raises(Exception) as info:
            self.model.state = "T" * (20 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_postal_code(self):
        """Test SMSTenDLCBrand.postal_code"""
        self.model.postal_code = "T" * 10
        assert self.model.get("postal_code") == "T" * 10
        
        with pytest.raises(Exception) as info:
            self.model.postal_code = "T" * (10 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_country(self):
        """Test SMSTenDLCBrand.country"""
        self.model.country = "T" * 2
        assert self.model.get("country") == "T" * 2
        
        with pytest.raises(Exception) as info:
            self.model.country = "T" * (2 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_email(self):
        """Test SMSTenDLCBrand.email"""
        self.model.email = "T" * 100
        assert self.model.get("email") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.email = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_stock_symbol(self):
        """Test SMSTenDLCBrand.stock_symbol"""
        self.model.stock_symbol = "T" * 10
        assert self.model.get("stock_symbol") == "T" * 10
        
        with pytest.raises(Exception) as info:
            self.model.stock_symbol = "T" * (10 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_stock_exchange(self):
        """Test SMSTenDLCBrand.stock_exchange"""
        self.model.stock_exchange = "NONE"
        assert self.model.get("stock_exchange") == "NONE"
        self.model.stock_exchange = "NASDAQ"
        assert self.model.get("stock_exchange") == "NASDAQ"
        self.model.stock_exchange = "NYSE"
        assert self.model.get("stock_exchange") == "NYSE"
        self.model.stock_exchange = "AMEX"
        assert self.model.get("stock_exchange") == "AMEX"
        self.model.stock_exchange = "AMX"
        assert self.model.get("stock_exchange") == "AMX"
        self.model.stock_exchange = "ASX"
        assert self.model.get("stock_exchange") == "ASX"
        self.model.stock_exchange = "B3"
        assert self.model.get("stock_exchange") == "B3"
        self.model.stock_exchange = "BME"
        assert self.model.get("stock_exchange") == "BME"
        self.model.stock_exchange = "BSE"
        assert self.model.get("stock_exchange") == "BSE"
        self.model.stock_exchange = "FRA"
        assert self.model.get("stock_exchange") == "FRA"
        self.model.stock_exchange = "ICEX"
        assert self.model.get("stock_exchange") == "ICEX"
        self.model.stock_exchange = "JPX"
        assert self.model.get("stock_exchange") == "JPX"
        self.model.stock_exchange = "JSE"
        assert self.model.get("stock_exchange") == "JSE"
        self.model.stock_exchange = "KRX"
        assert self.model.get("stock_exchange") == "KRX"
        self.model.stock_exchange = "LON"
        assert self.model.get("stock_exchange") == "LON"
        self.model.stock_exchange = "NSE"
        assert self.model.get("stock_exchange") == "NSE"
        self.model.stock_exchange = "OMX"
        assert self.model.get("stock_exchange") == "OMX"
        self.model.stock_exchange = "SEHK"
        assert self.model.get("stock_exchange") == "SEHK"
        self.model.stock_exchange = "SGX"
        assert self.model.get("stock_exchange") == "SGX"
        self.model.stock_exchange = "SSE"
        assert self.model.get("stock_exchange") == "SSE"
        self.model.stock_exchange = "STO"
        assert self.model.get("stock_exchange") == "STO"
        self.model.stock_exchange = "SWX"
        assert self.model.get("stock_exchange") == "SWX"
        self.model.stock_exchange = "SZSE"
        assert self.model.get("stock_exchange") == "SZSE"
        self.model.stock_exchange = "TSX"
        assert self.model.get("stock_exchange") == "TSX"
        self.model.stock_exchange = "TWSE"
        assert self.model.get("stock_exchange") == "TWSE"
        self.model.stock_exchange = "VSE"
        assert self.model.get("stock_exchange") == "VSE"
        self.model.stock_exchange = "OTHER"
        assert self.model.get("stock_exchange") == "OTHER"

    def test_stock_exchange_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.stock_exchange = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
    def test_ip_address(self):
        """Test SMSTenDLCBrand.ip_address"""
        self.model.ip_address = "T" * 50
        assert self.model.get("ip_address") == "T" * 50
        
        with pytest.raises(Exception) as info:
            self.model.ip_address = "T" * (50 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_website(self):
        """Test SMSTenDLCBrand.website"""
        self.model.website = "T" * 100
        assert self.model.get("website") == "T" * 100
        
        with pytest.raises(Exception) as info:
            self.model.website = "T" * (100 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_brand_relationship(self):
        """Test SMSTenDLCBrand.brand_relationship"""
        self.model.brand_relationship = "BASIC_ACCOUNT"
        assert self.model.get("brand_relationship") == "BASIC_ACCOUNT"
        self.model.brand_relationship = "SMALL_ACCOUNT"
        assert self.model.get("brand_relationship") == "SMALL_ACCOUNT"
        self.model.brand_relationship = "MEDIUM_ACCOUNT"
        assert self.model.get("brand_relationship") == "MEDIUM_ACCOUNT"
        self.model.brand_relationship = "LARGE_ACCOUNT"
        assert self.model.get("brand_relationship") == "LARGE_ACCOUNT"
        self.model.brand_relationship = "KEY_ACCOUNT"
        assert self.model.get("brand_relationship") == "KEY_ACCOUNT"

    def test_brand_relationship_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.brand_relationship = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
    def test_vertical(self):
        """Test SMSTenDLCBrand.vertical"""
        self.model.vertical = "T" * 50
        assert self.model.get("vertical") == "T" * 50
        
        with pytest.raises(Exception) as info:
            self.model.vertical = "T" * (50 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_alt_business_id(self):
        """Test SMSTenDLCBrand.alt_business_id"""
        self.model.alt_business_id = "T" * 50
        assert self.model.get("alt_business_id") == "T" * 50
        
        with pytest.raises(Exception) as info:
            self.model.alt_business_id = "T" * (50 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_alt_business_id_type(self):
        """Test SMSTenDLCBrand.alt_business_id_type"""
        self.model.alt_business_id_type = "NONE"
        assert self.model.get("alt_business_id_type") == "NONE"
        self.model.alt_business_id_type = "DUNS"
        assert self.model.get("alt_business_id_type") == "DUNS"
        self.model.alt_business_id_type = "GIIN"
        assert self.model.get("alt_business_id_type") == "GIIN"
        self.model.alt_business_id_type = "LEI"
        assert self.model.get("alt_business_id_type") == "LEI"

    def test_alt_business_id_type_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.alt_business_id_type = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
    def test_universal_ein(self):
        """Test SMSTenDLCBrand.universal_ein"""
        self.model.universal_ein = "TEST_STRING"
        assert self.model.get("universal_ein") == "TEST_STRING"

    def test_reference_id(self):
        """Test SMSTenDLCBrand.reference_id"""
        self.model.reference_id = "T" * 50
        assert self.model.get("reference_id") == "T" * 50
        
        with pytest.raises(Exception) as info:
            self.model.reference_id = "T" * (50 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_optional_attributes(self):
        """Test SMSTenDLCBrand.optional_attributes"""
        self.model.optional_attributes = {}
        assert self.model.get("optional_attributes") == {}

    def test_mock(self):
        """Test SMSTenDLCBrand.mock"""
        self.model.mock = False
        assert self.model.get("mock") == False

    def test_identity_status(self):
        """Test SMSTenDLCBrand.identity_status"""
        self.model.identity_status = "SELF_DECLARED"
        assert self.model.get("identity_status") == "SELF_DECLARED"
        self.model.identity_status = "UNVERIFIED"
        assert self.model.get("identity_status") == "UNVERIFIED"
        self.model.identity_status = "VERIFIED"
        assert self.model.get("identity_status") == "VERIFIED"
        self.model.identity_status = "VETTED_VERIFIED"
        assert self.model.get("identity_status") == "VETTED_VERIFIED"

    def test_identity_status_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.identity_status = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
    def test_create_date(self):
        """Test SMSTenDLCBrand.create_date"""
        self.model.create_date = datetime.fromtimestamp(1691592436)
        assert self.model.get("create_date") == datetime.fromtimestamp(1691592436)

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import unittest
from test.helpers import TestHelpers, MockPoolManager

import freeclimb
from freeclimb.api.default_api import DefaultApi  # noqa: E501

from freeclimb.model.play_beep import PlayBeep
from freeclimb.model.call_status import CallStatus
from freeclimb.model.message_direction import MessageDirection
from freeclimb.model.update_call_request_status import UpdateCallRequestStatus
from freeclimb.model.update_conference_request_status import UpdateConferenceRequestStatus

from freeclimb.model.account_request import AccountRequest
from freeclimb.model.account_result import AccountResult
from freeclimb.model.application_list import ApplicationList
from freeclimb.model.application_request import ApplicationRequest
from freeclimb.model.application_result import ApplicationResult
from freeclimb.model.available_number_list import AvailableNumberList
from freeclimb.model.buy_incoming_number_request import BuyIncomingNumberRequest
from freeclimb.model.call_list import CallList
from freeclimb.model.call_result import CallResult
from freeclimb.model.conference_list import ConferenceList
from freeclimb.model.conference_participant_list import ConferenceParticipantList
from freeclimb.model.conference_participant_result import ConferenceParticipantResult
from freeclimb.model.conference_result import ConferenceResult
from freeclimb.model.create_conference_request import CreateConferenceRequest
from freeclimb.model.filter_logs_request import FilterLogsRequest
from freeclimb.model.incoming_number_list import IncomingNumberList
from freeclimb.model.incoming_number_request import IncomingNumberRequest
from freeclimb.model.incoming_number_result import IncomingNumberResult
from freeclimb.model.log_list import LogList
from freeclimb.model.make_call_request import MakeCallRequest
from freeclimb.model.message_request import MessageRequest
from freeclimb.model.message_result import MessageResult
from freeclimb.model.messages_list import MessagesList
from freeclimb.model.queue_list import QueueList
from freeclimb.model.queue_member import QueueMember
from freeclimb.model.queue_member_list import QueueMemberList
from freeclimb.model.queue_request import QueueRequest
from freeclimb.model.queue_result import QueueResult
from freeclimb.model.recording_list import RecordingList
from freeclimb.model.recording_result import RecordingResult
from freeclimb.model.update_call_request import UpdateCallRequest
from freeclimb.model.update_conference_participant_request import UpdateConferenceParticipantRequest
from freeclimb.model.update_conference_request import UpdateConferenceRequest

from io import BufferedReader as file_type

from freeclimb.model.account_request import AccountRequest
from freeclimb.model.account_result import AccountResult
from freeclimb.model.application_list import ApplicationList
from freeclimb.model.application_request import ApplicationRequest
from freeclimb.model.application_result import ApplicationResult
from freeclimb.model.available_number_list import AvailableNumberList
from freeclimb.model.buy_incoming_number_request import BuyIncomingNumberRequest
from freeclimb.model.call_list import CallList
from freeclimb.model.call_result import CallResult
from freeclimb.model.call_status import CallStatus
from freeclimb.model.conference_list import ConferenceList
from freeclimb.model.conference_participant_list import ConferenceParticipantList
from freeclimb.model.conference_participant_result import ConferenceParticipantResult
from freeclimb.model.conference_result import ConferenceResult
from freeclimb.model.create_conference_request import CreateConferenceRequest
from freeclimb.model.filter_logs_request import FilterLogsRequest
from freeclimb.model.incoming_number_list import IncomingNumberList
from freeclimb.model.incoming_number_request import IncomingNumberRequest
from freeclimb.model.incoming_number_result import IncomingNumberResult
from freeclimb.model.log_list import LogList
from freeclimb.model.make_call_request import MakeCallRequest
from freeclimb.model.message_direction import MessageDirection
from freeclimb.model.message_request import MessageRequest
from freeclimb.model.message_result import MessageResult
from freeclimb.model.messages_list import MessagesList
from freeclimb.model.queue_list import QueueList
from freeclimb.model.queue_member import QueueMember
from freeclimb.model.queue_member_list import QueueMemberList
from freeclimb.model.queue_request import QueueRequest
from freeclimb.model.queue_result import QueueResult
from freeclimb.model.recording_list import RecordingList
from freeclimb.model.recording_result import RecordingResult
from freeclimb.model.sms_ten_dlc_brand import SMSTenDLCBrand
from freeclimb.model.sms_ten_dlc_brands_list_result import SMSTenDLCBrandsListResult
from freeclimb.model.sms_ten_dlc_campaign import SMSTenDLCCampaign
from freeclimb.model.sms_ten_dlc_campaigns_list_result import SMSTenDLCCampaignsListResult
from freeclimb.model.sms_ten_dlc_partner_campaign import SMSTenDLCPartnerCampaign
from freeclimb.model.sms_ten_dlc_partner_campaigns_list_result import SMSTenDLCPartnerCampaignsListResult
from freeclimb.model.update_call_request import UpdateCallRequest
from freeclimb.model.update_conference_participant_request import UpdateConferenceParticipantRequest
from freeclimb.model.update_conference_request import UpdateConferenceRequest

import json

class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        configuration = freeclimb.Configuration(
            host = 'http://127.0.0.1:4010',
            username = 'TEST_ACCOUNT_ID',
            password = 'TEST_API_KEY'
        )

        self.api = DefaultApi(freeclimb.ApiClient(configuration))  # noqa: E501

    def tearDown(self):
        pass

    def test_buy_a_phone_number(self):
        """Test case for buy_a_phone_number

        Buy a Phone Number  # noqa: E501
        """

        buy_incoming_number_request = buy_incoming_number_request_buy_a_phone_number_test_value


        api_response = self.api.buy_a_phone_number(buy_incoming_number_request=buy_incoming_number_request)
        
        assert isinstance(api_response, IncomingNumberResult)

    def test_create_a_conference(self):
        """Test case for create_a_conference

        Create a Conference  # noqa: E501
        """

        create_conference_request = create_conference_request_create_a_conference_test_value


        api_response = self.api.create_a_conference(create_conference_request=create_conference_request)
        
        assert isinstance(api_response, ConferenceResult)

    def test_create_a_queue(self):
        """Test case for create_a_queue

        Create a Queue  # noqa: E501
        """

        queue_request = queue_request_create_a_queue_test_value


        api_response = self.api.create_a_queue(queue_request=queue_request)
        
        assert isinstance(api_response, QueueResult)

    def test_create_an_application(self):
        """Test case for create_an_application

        Create an application  # noqa: E501
        """

        application_request = application_request_create_an_application_test_value


        api_response = self.api.create_an_application(application_request=application_request)
        
        assert isinstance(api_response, ApplicationResult)

    def test_delete_a_recording(self):
        """Test case for delete_a_recording

        Delete a Recording  # noqa: E501
        """

        recording_id = recording_id_delete_a_recording_test_value


        api_response = self.api.delete_a_recording(recording_id=recording_id)
        
        

    def test_delete_an_application(self):
        """Test case for delete_an_application

        Delete an application  # noqa: E501
        """

        application_id = application_id_delete_an_application_test_value


        api_response = self.api.delete_an_application(application_id=application_id)
        
        

    def test_delete_an_incoming_number(self):
        """Test case for delete_an_incoming_number

        Delete an Incoming Number  # noqa: E501
        """

        phone_number_id = phone_number_id_delete_an_incoming_number_test_value


        api_response = self.api.delete_an_incoming_number(phone_number_id=phone_number_id)
        
        

    def test_dequeue_a_member(self):
        """Test case for dequeue_a_member

        Dequeue a Member  # noqa: E501
        """

        queue_id = queue_id_dequeue_a_member_test_value
        call_id = call_id_dequeue_a_member_test_value


        api_response = self.api.dequeue_a_member(queue_id=queue_id,call_id=call_id)
        
        assert isinstance(api_response, QueueMember)

    def test_dequeue_head_member(self):
        """Test case for dequeue_head_member

        Dequeue Head Member  # noqa: E501
        """

        queue_id = queue_id_dequeue_head_member_test_value


        api_response = self.api.dequeue_head_member(queue_id=queue_id)
        
        assert isinstance(api_response, QueueMember)

    def test_download_a_recording_file(self):
        """Test case for download_a_recording_file

        Download a Recording File  # noqa: E501
        """

        recording_id = recording_id_download_a_recording_file_test_value


        api_response = self.api.download_a_recording_file(recording_id=recording_id)
        
        assert isinstance(api_response, file_type)

    def test_filter_logs(self):
        """Test case for filter_logs

        Filter Logs  # noqa: E501
        """

        filter_logs_request = filter_logs_request_filter_logs_test_value


        api_response = self.api.filter_logs(filter_logs_request=filter_logs_request)
        
        assert isinstance(api_response, LogList)

    def test_get_a_call(self):
        """Test case for get_a_call

        Get a Call  # noqa: E501
        """

        call_id = call_id_get_a_call_test_value


        api_response = self.api.get_a_call(call_id=call_id)
        
        assert isinstance(api_response, CallResult)

    def test_get_a_conference(self):
        """Test case for get_a_conference

        Get a Conference  # noqa: E501
        """

        conference_id = conference_id_get_a_conference_test_value


        api_response = self.api.get_a_conference(conference_id=conference_id)
        
        assert isinstance(api_response, ConferenceResult)

    def test_get_a_member(self):
        """Test case for get_a_member

        Get a Member  # noqa: E501
        """

        queue_id = queue_id_get_a_member_test_value
        call_id = call_id_get_a_member_test_value


        api_response = self.api.get_a_member(queue_id=queue_id,call_id=call_id)
        
        assert isinstance(api_response, QueueMember)

    def test_get_a_participant(self):
        """Test case for get_a_participant

        Get a Participant  # noqa: E501
        """

        conference_id = conference_id_get_a_participant_test_value
        call_id = call_id_get_a_participant_test_value


        api_response = self.api.get_a_participant(conference_id=conference_id,call_id=call_id)
        
        assert isinstance(api_response, ConferenceParticipantResult)

    def test_get_a_queue(self):
        """Test case for get_a_queue

        Get a Queue  # noqa: E501
        """

        queue_id = queue_id_get_a_queue_test_value


        api_response = self.api.get_a_queue(queue_id=queue_id)
        
        assert isinstance(api_response, QueueResult)

    def test_get_a_recording(self):
        """Test case for get_a_recording

        Get a Recording  # noqa: E501
        """

        recording_id = recording_id_get_a_recording_test_value


        api_response = self.api.get_a_recording(recording_id=recording_id)
        
        assert isinstance(api_response, RecordingResult)

    def test_get_an_account(self):
        """Test case for get_an_account

        Get an Account  # noqa: E501
        """



        api_response = self.api.get_an_account()
        
        assert isinstance(api_response, AccountResult)

    def test_get_an_application(self):
        """Test case for get_an_application

        Get an Application  # noqa: E501
        """

        application_id = application_id_get_an_application_test_value


        api_response = self.api.get_an_application(application_id=application_id)
        
        assert isinstance(api_response, ApplicationResult)

    def test_get_an_incoming_number(self):
        """Test case for get_an_incoming_number

        Get an Incoming Number  # noqa: E501
        """

        phone_number_id = phone_number_id_get_an_incoming_number_test_value


        api_response = self.api.get_an_incoming_number(phone_number_id=phone_number_id)
        
        assert isinstance(api_response, IncomingNumberResult)

    def test_get_an_sms_message(self):
        """Test case for get_an_sms_message

        Get an SMS Message  # noqa: E501
        """

        message_id = message_id_get_an_sms_message_test_value


        api_response = self.api.get_an_sms_message(message_id=message_id)
        
        assert isinstance(api_response, MessageResult)

    def test_get_head_member(self):
        """Test case for get_head_member

        Get Head Member  # noqa: E501
        """

        queue_id = queue_id_get_head_member_test_value


        api_response = self.api.get_head_member(queue_id=queue_id)
        
        assert isinstance(api_response, QueueMember)

    def test_get_ten_dlc_sms_brand(self):
        """Test case for get_ten_dlc_sms_brand

        Get a 10DLC SMS Brand  # noqa: E501
        """

        brand_id = brand_id_get_ten_dlc_sms_brand_test_value


        api_response = self.api.get_ten_dlc_sms_brand(brand_id=brand_id)
        
        assert isinstance(api_response, SMSTenDLCBrand)

    def test_get_ten_dlc_sms_brands(self):
        """Test case for get_ten_dlc_sms_brands

        Get list of SMS 10DLC Brands  # noqa: E501
        """



        api_response = self.api.get_ten_dlc_sms_brands()
        
        assert isinstance(api_response, SMSTenDLCBrandsListResult)

    def test_get_ten_dlc_sms_campaign(self):
        """Test case for get_ten_dlc_sms_campaign

        Get a 10DLC SMS Campaign  # noqa: E501
        """

        campaign_id = campaign_id_get_ten_dlc_sms_campaign_test_value


        api_response = self.api.get_ten_dlc_sms_campaign(campaign_id=campaign_id)
        
        assert isinstance(api_response, SMSTenDLCCampaign)

    def test_get_ten_dlc_sms_campaigns(self):
        """Test case for get_ten_dlc_sms_campaigns

        Get list of SMS 10DLC Campaigns  # noqa: E501
        """

        brand_id = brand_id_get_ten_dlc_sms_campaigns_test_value


        api_response = self.api.get_ten_dlc_sms_campaigns(brand_id=brand_id)
        
        assert isinstance(api_response, SMSTenDLCCampaignsListResult)

    def test_get_ten_dlc_sms_partner_campaign(self):
        """Test case for get_ten_dlc_sms_partner_campaign

        Get a 10DLC SMS Partner Campaign  # noqa: E501
        """

        campaign_id = campaign_id_get_ten_dlc_sms_partner_campaign_test_value


        api_response = self.api.get_ten_dlc_sms_partner_campaign(campaign_id=campaign_id)
        
        assert isinstance(api_response, SMSTenDLCPartnerCampaign)

    def test_get_ten_dlc_sms_partner_campaigns(self):
        """Test case for get_ten_dlc_sms_partner_campaigns

        Get list of SMS 10DLC Partner Campaigns  # noqa: E501
        """

        brand_id = brand_id_get_ten_dlc_sms_partner_campaigns_test_value


        api_response = self.api.get_ten_dlc_sms_partner_campaigns(brand_id=brand_id)
        
        assert isinstance(api_response, SMSTenDLCPartnerCampaignsListResult)

    def test_list_active_queues(self):
        """Test case for list_active_queues

        List Active Queues  # noqa: E501
        """

        alias = alias_list_active_queues_test_value


        api_response = self.api.list_active_queues(alias=alias)
        
        assert isinstance(api_response, QueueList)

    def test_list_all_account_logs(self):
        """Test case for list_all_account_logs

        List All Account Logs  # noqa: E501
        """



        api_response = self.api.list_all_account_logs()
        
        assert isinstance(api_response, LogList)

    def test_list_applications(self):
        """Test case for list_applications

        List applications  # noqa: E501
        """

        alias = alias_list_applications_test_value


        api_response = self.api.list_applications(alias=alias)
        
        assert isinstance(api_response, ApplicationList)

    def test_list_available_numbers(self):
        """Test case for list_available_numbers

        List available numbers  # noqa: E501
        """

        phone_number = phone_number_list_available_numbers_test_value
        region = region_list_available_numbers_test_value
        country = country_list_available_numbers_test_value
        voice_enabled = voice_enabled_list_available_numbers_test_value
        sms_enabled = sms_enabled_list_available_numbers_test_value
        capabilities_voice = capabilities_voice_list_available_numbers_test_value
        capabilities_sms = capabilities_sms_list_available_numbers_test_value
        capabilities_toll_free = capabilities_toll_free_list_available_numbers_test_value
        capabilities_ten_dlc = capabilities_ten_dlc_list_available_numbers_test_value
        capabilities_short_code = capabilities_short_code_list_available_numbers_test_value


        api_response = self.api.list_available_numbers(phone_number=phone_number,region=region,country=country,voice_enabled=voice_enabled,sms_enabled=sms_enabled,capabilities_voice=capabilities_voice,capabilities_sms=capabilities_sms,capabilities_toll_free=capabilities_toll_free,capabilities_ten_dlc=capabilities_ten_dlc,capabilities_short_code=capabilities_short_code)
        
        assert isinstance(api_response, AvailableNumberList)

    def test_list_call_logs(self):
        """Test case for list_call_logs

        List Call Logs  # noqa: E501
        """

        call_id = call_id_list_call_logs_test_value


        api_response = self.api.list_call_logs(call_id=call_id)
        
        assert isinstance(api_response, LogList)

    def test_list_call_recordings(self):
        """Test case for list_call_recordings

        List Call Recordings  # noqa: E501
        """

        call_id = call_id_list_call_recordings_test_value
        date_created = date_created_list_call_recordings_test_value


        api_response = self.api.list_call_recordings(call_id=call_id,date_created=date_created)
        
        assert isinstance(api_response, RecordingList)

    def test_list_calls(self):
        """Test case for list_calls

        List Calls  # noqa: E501
        """

        active = active_list_calls_test_value
        to = to_list_calls_test_value
        _from = _from_list_calls_test_value
        status = status_list_calls_test_value
        start_time = start_time_list_calls_test_value
        end_time = end_time_list_calls_test_value
        parent_call_id = parent_call_id_list_calls_test_value
        application_id = application_id_list_calls_test_value


        api_response = self.api.list_calls(active=active,to=to,_from=_from,status=status,start_time=start_time,end_time=end_time,parent_call_id=parent_call_id,application_id=application_id)
        
        assert isinstance(api_response, CallList)

    def test_list_conferences(self):
        """Test case for list_conferences

        List Conferences  # noqa: E501
        """

        status = status_list_conferences_test_value
        alias = alias_list_conferences_test_value
        date_created = date_created_list_conferences_test_value
        date_updated = date_updated_list_conferences_test_value


        api_response = self.api.list_conferences(status=status,alias=alias,date_created=date_created,date_updated=date_updated)
        
        assert isinstance(api_response, ConferenceList)

    def test_list_incoming_numbers(self):
        """Test case for list_incoming_numbers

        List Incoming Numbers  # noqa: E501
        """

        phone_number = phone_number_list_incoming_numbers_test_value
        alias = alias_list_incoming_numbers_test_value
        region = region_list_incoming_numbers_test_value
        country = country_list_incoming_numbers_test_value
        application_id = application_id_list_incoming_numbers_test_value
        has_application = has_application_list_incoming_numbers_test_value
        voice_enabled = voice_enabled_list_incoming_numbers_test_value
        sms_enabled = sms_enabled_list_incoming_numbers_test_value
        has_campaign = has_campaign_list_incoming_numbers_test_value
        capabilities_voice = capabilities_voice_list_incoming_numbers_test_value
        capabilities_sms = capabilities_sms_list_incoming_numbers_test_value
        capabilities_toll_free = capabilities_toll_free_list_incoming_numbers_test_value
        capabilities_ten_dlc = capabilities_ten_dlc_list_incoming_numbers_test_value
        capabilities_short_code = capabilities_short_code_list_incoming_numbers_test_value
        offnet = offnet_list_incoming_numbers_test_value


        api_response = self.api.list_incoming_numbers(phone_number=phone_number,alias=alias,region=region,country=country,application_id=application_id,has_application=has_application,voice_enabled=voice_enabled,sms_enabled=sms_enabled,has_campaign=has_campaign,capabilities_voice=capabilities_voice,capabilities_sms=capabilities_sms,capabilities_toll_free=capabilities_toll_free,capabilities_ten_dlc=capabilities_ten_dlc,capabilities_short_code=capabilities_short_code,offnet=offnet)
        
        assert isinstance(api_response, IncomingNumberList)

    def test_list_members(self):
        """Test case for list_members

        List Members  # noqa: E501
        """

        queue_id = queue_id_list_members_test_value


        api_response = self.api.list_members(queue_id=queue_id)
        
        assert isinstance(api_response, QueueMemberList)

    def test_list_participants(self):
        """Test case for list_participants

        List Participants  # noqa: E501
        """

        conference_id = conference_id_list_participants_test_value
        talk = talk_list_participants_test_value
        listen = listen_list_participants_test_value


        api_response = self.api.list_participants(conference_id=conference_id,talk=talk,listen=listen)
        
        assert isinstance(api_response, ConferenceParticipantList)

    def test_list_recordings(self):
        """Test case for list_recordings

        List Recordings  # noqa: E501
        """

        call_id = call_id_list_recordings_test_value
        conference_id = conference_id_list_recordings_test_value
        date_created = date_created_list_recordings_test_value


        api_response = self.api.list_recordings(call_id=call_id,conference_id=conference_id,date_created=date_created)
        
        assert isinstance(api_response, RecordingList)

    def test_list_sms_messages(self):
        """Test case for list_sms_messages

        List SMS Messages  # noqa: E501
        """

        to = to_list_sms_messages_test_value
        _from = _from_list_sms_messages_test_value
        begin_time = begin_time_list_sms_messages_test_value
        end_time = end_time_list_sms_messages_test_value
        direction = direction_list_sms_messages_test_value
        campaign_id = campaign_id_list_sms_messages_test_value
        brand_id = brand_id_list_sms_messages_test_value
        is10_dlc = is10_dlc_list_sms_messages_test_value


        api_response = self.api.list_sms_messages(to=to,_from=_from,begin_time=begin_time,end_time=end_time,direction=direction,campaign_id=campaign_id,brand_id=brand_id,is10_dlc=is10_dlc)
        
        assert isinstance(api_response, MessagesList)

    def test_make_a_call(self):
        """Test case for make_a_call

        Make a Call  # noqa: E501
        """

        make_call_request = make_call_request_make_a_call_test_value


        api_response = self.api.make_a_call(make_call_request=make_call_request)
        
        assert isinstance(api_response, CallResult)

    def test_remove_a_participant(self):
        """Test case for remove_a_participant

        Remove a Participant  # noqa: E501
        """

        conference_id = conference_id_remove_a_participant_test_value
        call_id = call_id_remove_a_participant_test_value


        api_response = self.api.remove_a_participant(conference_id=conference_id,call_id=call_id)
        
        

    def test_send_an_sms_message(self):
        """Test case for send_an_sms_message

        Send an SMS Message  # noqa: E501
        """

        message_request = message_request_send_an_sms_message_test_value


        api_response = self.api.send_an_sms_message(message_request=message_request)
        
        assert isinstance(api_response, MessageResult)

    def test_stream_a_recording_file(self):
        """Test case for stream_a_recording_file

        Stream a Recording File  # noqa: E501
        """

        recording_id = recording_id_stream_a_recording_file_test_value


        api_response = self.api.stream_a_recording_file(recording_id=recording_id)
        
        assert isinstance(api_response, file_type)

    def test_update_a_conference(self):
        """Test case for update_a_conference

        Update a Conference  # noqa: E501
        """

        conference_id = conference_id_update_a_conference_test_value
        update_conference_request = update_conference_request_update_a_conference_test_value


        api_response = self.api.update_a_conference(conference_id=conference_id,update_conference_request=update_conference_request)
        
        assert isinstance(api_response, ConferenceResult)

    def test_update_a_live_call(self):
        """Test case for update_a_live_call

        Update a Live Call  # noqa: E501
        """

        call_id = call_id_update_a_live_call_test_value
        update_call_request = update_call_request_update_a_live_call_test_value


        api_response = self.api.update_a_live_call(call_id=call_id,update_call_request=update_call_request)
        
        

    def test_update_a_participant(self):
        """Test case for update_a_participant

        Update a Participant  # noqa: E501
        """

        conference_id = conference_id_update_a_participant_test_value
        call_id = call_id_update_a_participant_test_value
        update_conference_participant_request = update_conference_participant_request_update_a_participant_test_value


        api_response = self.api.update_a_participant(conference_id=conference_id,call_id=call_id,update_conference_participant_request=update_conference_participant_request)
        
        assert isinstance(api_response, ConferenceParticipantResult)

    def test_update_a_queue(self):
        """Test case for update_a_queue

        Update a Queue  # noqa: E501
        """

        queue_id = queue_id_update_a_queue_test_value
        queue_request = queue_request_update_a_queue_test_value


        api_response = self.api.update_a_queue(queue_id=queue_id,queue_request=queue_request)
        
        assert isinstance(api_response, QueueResult)

    def test_update_an_account(self):
        """Test case for update_an_account

        Manage an account  # noqa: E501
        """

        account_request = account_request_update_an_account_test_value


        api_response = self.api.update_an_account(account_request=account_request)
        
        

    def test_update_an_application(self):
        """Test case for update_an_application

        Update an application  # noqa: E501
        """

        application_id = application_id_update_an_application_test_value
        application_request = application_request_update_an_application_test_value


        api_response = self.api.update_an_application(application_id=application_id,application_request=application_request)
        
        assert isinstance(api_response, ApplicationResult)

    def test_update_an_incoming_number(self):
        """Test case for update_an_incoming_number

        Update an Incoming Number  # noqa: E501
        """

        phone_number_id = phone_number_id_update_an_incoming_number_test_value
        incoming_number_request = incoming_number_request_update_an_incoming_number_test_value


        api_response = self.api.update_an_incoming_number(phone_number_id=phone_number_id,incoming_number_request=incoming_number_request)
        
        assert isinstance(api_response, IncomingNumberResult)


buy_incoming_number_request_buy_a_phone_number_test_value = BuyIncomingNumberRequest(
            phone_number="phone_number_example",
            alias="alias_example",
            application_id="application_id_example",
)

create_conference_request_create_a_conference_test_value = CreateConferenceRequest(
            alias="alias_example",
            play_beep=PlayBeep.ALWAYS,
            record=True,
            wait_url="wait_url_example",
            status_callback_url="status_callback_url_example",
)

queue_request_create_a_queue_test_value = QueueRequest(
        alias="alias_example",
        max_size=100,
)


application_request_create_an_application_test_value = ApplicationRequest(
            alias="alias_example",
            voice_url="voice_url_example",
            voice_fallback_url="voice_fallback_url_example",
            call_connect_url="call_connect_url_example",
            status_callback_url="status_callback_url_example",
            sms_url="sms_url_example",
            sms_fallback_url="sms_fallback_url_example",
)
    
recording_id_delete_a_recording_test_value = "recordingId_example"

application_id_delete_an_application_test_value = "applicationId_example"

phone_number_id_delete_an_incoming_number_test_value = "phoneNumberId_example"

queue_id_dequeue_a_member_test_value = "queueId_example"

call_id_dequeue_a_member_test_value = "callId_example"

queue_id_dequeue_head_member_test_value = "queueId_example"

recording_id_download_a_recording_file_test_value = "recordingId_example"

filter_logs_request_filter_logs_test_value = FilterLogsRequest(
            pql="pql_example",
)
call_id_get_a_call_test_value = "callId_example"

conference_id_get_a_conference_test_value = "conferenceId_example"

queue_id_get_a_member_test_value = "queueId_example"

call_id_get_a_member_test_value = "callId_example"

conference_id_get_a_participant_test_value = "conferenceId_example"

call_id_get_a_participant_test_value = "callId_example"

queue_id_get_a_queue_test_value = "queueId_example"

recording_id_get_a_recording_test_value = "recordingId_example"

application_id_get_an_application_test_value = "applicationId_example"

phone_number_id_get_an_incoming_number_test_value = "phoneNumberId_example"

message_id_get_an_sms_message_test_value = "messageId_example"

queue_id_get_head_member_test_value = "queueId_example"

alias_list_active_queues_test_value = "alias_example"

alias_list_applications_test_value = "alias_example"

phone_number_list_available_numbers_test_value = "phoneNumberId_example"

region_list_available_numbers_test_value = "region_example"

country_list_available_numbers_test_value = "country_example"

voice_enabled_list_available_numbers_test_value = True

sms_enabled_list_available_numbers_test_value = True

capabilities_voice_list_available_numbers_test_value = True

capabilities_sms_list_available_numbers_test_value = True

capabilities_toll_free_list_available_numbers_test_value = True

capabilities_ten_dlc_list_available_numbers_test_value = True

capabilities_short_code_list_available_numbers_test_value = True

call_id_list_call_logs_test_value = "callId_example"

call_id_list_call_recordings_test_value = "callId_example"

date_created_list_call_recordings_test_value = "dateCreated_example"

active_list_calls_test_value = False 

to_list_calls_test_value = "to_example"

_from_list_calls_test_value = "from_example"

status_list_calls_test_value = CallStatus.QUEUED

start_time_list_calls_test_value = "startTime_example"

end_time_list_calls_test_value = "endTime_example"

parent_call_id_list_calls_test_value = "parentCallId_example"

application_id_list_calls_test_value = ['AP0123456789ABCDEFabcedf000000000000000001','AP0123456789ABCDEFabcedf000000000000000002', 'AP0123456789ABCDEFabcedf000000000000000003']

status_list_conferences_test_value = "status_example"

alias_list_conferences_test_value = "alias_example"

date_created_list_conferences_test_value = "dateCreated_example"

date_updated_list_conferences_test_value = "dateUpdated_example"
    
phone_number_list_incoming_numbers_test_value = "phoneNumberId_example"

alias_list_incoming_numbers_test_value = "alias_example"

region_list_incoming_numbers_test_value = "region_example"

country_list_incoming_numbers_test_value = "country_example"

application_id_list_incoming_numbers_test_value = "applicationId_example"

has_application_list_incoming_numbers_test_value = False

voice_enabled_list_incoming_numbers_test_value = True

sms_enabled_list_incoming_numbers_test_value = True

capabilities_voice_list_incoming_numbers_test_value = True

capabilities_sms_list_incoming_numbers_test_value = True

capabilities_toll_free_list_incoming_numbers_test_value = True

capabilities_ten_dlc_list_incoming_numbers_test_value = True

capabilities_short_code_list_incoming_numbers_test_value = True

queue_id_list_members_test_value = "queueId_example"

conference_id_list_participants_test_value = "conferenceId_example"

talk_list_participants_test_value = True

listen_list_participants_test_value = True

to_list_sms_messages_test_value="to_example"

_from_list_sms_messages_test_value = "from_example"

begin_time_list_sms_messages_test_value = "beginTime_example"

end_time_list_sms_messages_test_value = "endTime_example"

direction_list_sms_messages_test_value = MessageDirection.INBOUND

conference_id_remove_a_participant_test_value = "conferenceId_example"

call_id_remove_a_participant_test_value = "callId_example"

recording_id_stream_a_recording_file_test_value = "recordingId_example"

conference_id_update_a_conference_test_value = "conferenceId_example"

call_id_update_a_live_call_test_value = "callId_example"

conference_id_update_a_participant_test_value = "conferenceId_example"

call_id_update_a_participant_test_value = "callId_example"

queue_id_update_a_queue_test_value = "queueId_example"

application_id_update_an_application_test_value = "applicationId_example"

phone_number_id_update_an_incoming_number_test_value = "phoneNumberId_example"

offnet_list_incoming_numbers_test_value = True

call_id_list_recordings_test_value = "callId_example"

conference_id_list_recordings_test_value = "conferenceId_example"

date_created_list_recordings_test_value = "dateCreated_example"

brand_id_get_ten_dlc_sms_campaigns_test_value = "BX56XX4"

brand_id_get_ten_dlc_sms_partner_campaigns_test_value = "BX56XX4"

brand_id_get_ten_dlc_sms_brand_test_value = "BX56XX4"

campaign_id_get_ten_dlc_sms_campaign_test_value = "CX56XX4"

campaign_id_get_ten_dlc_sms_partner_campaign_test_value = "CX56XX4"

has_campaign_list_incoming_numbers_test_value = True

campaign_id_list_sms_messages_test_value = "CX56XX4"

brand_id_list_sms_messages_test_value = "BX56XX4"

is10_dlc_list_sms_messages_test_value = True

queue_request_update_a_queue_test_value = QueueRequest(
        alias="alias_example",
        max_size=100,
)

application_request_update_an_application_test_value = ApplicationRequest(
            alias="alias_example",
            voice_url="voice_url_example",
            voice_fallback_url="voice_fallback_url_example",
            call_connect_url="call_connect_url_example",
            status_callback_url="status_callback_url_example",
            sms_url="sms_url_example",
            sms_fallback_url="sms_fallback_url_example",
)
make_call_request_make_a_call_test_value = MakeCallRequest(
    _from="_from_example",
    to="to_example",
    application_id="application_id_example",
    send_digits="send_digits_example",
    if_machine="if_machine_example",
    if_machine_url="if_machine_url_example",
    timeout=30,
    parent_call_id="parent_call_id_example",
    privacy_mode=True,
    call_connect_url="call_connect_url_example",
)

message_request_send_an_sms_message_test_value = MessageRequest(
        _from="_from_example",
        to="to_example",
        text="Example Text",
)

update_conference_request_update_a_conference_test_value = UpdateConferenceRequest(
        alias="alias_example",
        play_beep=PlayBeep.ALWAYS,
        status=UpdateConferenceRequestStatus.EMPTY,
)

update_call_request_update_a_live_call_test_value = UpdateCallRequest(
        status=UpdateCallRequestStatus.CANCELED,
)

update_conference_participant_request_update_a_participant_test_value = UpdateConferenceParticipantRequest(
        talk=True,
        listen=True,
)

account_request_update_an_account_test_value = AccountRequest(
        alias="alias_example",
        label="label_example",
)

incoming_number_request_update_an_incoming_number_test_value = IncomingNumberRequest(
        application_id="application_id_example",
        alias="alias_example",
)



if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.sms_ten_dlc_partner_campaign_brand import SMSTenDLCPartnerCampaignBrand
globals()['SMSTenDLCPartnerCampaignBrand'] = SMSTenDLCPartnerCampaignBrand

from freeclimb.model.sms_ten_dlc_partner_campaign import SMSTenDLCPartnerCampaign  # noqa: E501

class TestSMSTenDLCPartnerCampaign(unittest.TestCase):
    """SMSTenDLCPartnerCampaign unit test stubs"""

    def setUp(self):
        self.model = SMSTenDLCPartnerCampaign(
            campaign_id="",
            brand_id="",
            usecase="",
            description="",
        )
    
    def test_account_id(self):
        """Test SMSTenDLCPartnerCampaign.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_campaign_id(self):
        """Test SMSTenDLCPartnerCampaign.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_status(self):
        """Test SMSTenDLCPartnerCampaign.status"""
        self.model.status = "ACTIVE"
        assert self.model.get("status") == "ACTIVE"
        self.model.status = "EXPIRED"
        assert self.model.get("status") == "EXPIRED"

    def test_status_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.status = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
    def test_create_date(self):
        """Test SMSTenDLCPartnerCampaign.create_date"""
        self.model.create_date = datetime.fromtimestamp(1691592436)
        assert self.model.get("create_date") == datetime.fromtimestamp(1691592436)

    def test_brand_id(self):
        """Test SMSTenDLCPartnerCampaign.brand_id"""
        self.model.brand_id = "T" * 8
        assert self.model.get("brand_id") == "T" * 8
        
        with pytest.raises(Exception) as info:
            self.model.brand_id = "T" * (8 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_usecase(self):
        """Test SMSTenDLCPartnerCampaign.usecase"""
        self.model.usecase = "T" * 20
        assert self.model.get("usecase") == "T" * 20
        
        with pytest.raises(Exception) as info:
            self.model.usecase = "T" * (20 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_description(self):
        """Test SMSTenDLCPartnerCampaign.description"""
        self.model.description = "T" * 4096
        assert self.model.get("description") == "T" * 4096
        
        with pytest.raises(Exception) as info:
            self.model.description = "T" * (4096 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_embedded_link(self):
        """Test SMSTenDLCPartnerCampaign.embedded_link"""
        self.model.embedded_link = False
        assert self.model.get("embedded_link") == False

    def test_embedded_phone(self):
        """Test SMSTenDLCPartnerCampaign.embedded_phone"""
        self.model.embedded_phone = False
        assert self.model.get("embedded_phone") == False

    def test_affiliate_marketing(self):
        """Test SMSTenDLCPartnerCampaign.affiliate_marketing"""
        self.model.affiliate_marketing = False
        assert self.model.get("affiliate_marketing") == False

    def test_number_pool(self):
        """Test SMSTenDLCPartnerCampaign.number_pool"""
        self.model.number_pool = False
        assert self.model.get("number_pool") == False

    def test_age_gated(self):
        """Test SMSTenDLCPartnerCampaign.age_gated"""
        self.model.age_gated = False
        assert self.model.get("age_gated") == False

    def test_direct_lending(self):
        """Test SMSTenDLCPartnerCampaign.direct_lending"""
        self.model.direct_lending = False
        assert self.model.get("direct_lending") == False

    def test_subscriber_optin(self):
        """Test SMSTenDLCPartnerCampaign.subscriber_optin"""
        self.model.subscriber_optin = False
        assert self.model.get("subscriber_optin") == False

    def test_subscriber_optout(self):
        """Test SMSTenDLCPartnerCampaign.subscriber_optout"""
        self.model.subscriber_optout = False
        assert self.model.get("subscriber_optout") == False

    def test_subscriber_help(self):
        """Test SMSTenDLCPartnerCampaign.subscriber_help"""
        self.model.subscriber_help = False
        assert self.model.get("subscriber_help") == False

    def test_sample1(self):
        """Test SMSTenDLCPartnerCampaign.sample1"""
        self.model.sample1 = "T" * 1024
        assert self.model.get("sample1") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample1 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample2(self):
        """Test SMSTenDLCPartnerCampaign.sample2"""
        self.model.sample2 = "T" * 1024
        assert self.model.get("sample2") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample2 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample3(self):
        """Test SMSTenDLCPartnerCampaign.sample3"""
        self.model.sample3 = "T" * 1024
        assert self.model.get("sample3") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample3 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample4(self):
        """Test SMSTenDLCPartnerCampaign.sample4"""
        self.model.sample4 = "T" * 1024
        assert self.model.get("sample4") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample4 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample5(self):
        """Test SMSTenDLCPartnerCampaign.sample5"""
        self.model.sample5 = "T" * 1024
        assert self.model.get("sample5") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample5 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_message_flow(self):
        """Test SMSTenDLCPartnerCampaign.message_flow"""
        self.model.message_flow = "T" * 2048
        assert self.model.get("message_flow") == "T" * 2048
        
        with pytest.raises(Exception) as info:
            self.model.message_flow = "T" * (2048 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_help_message(self):
        """Test SMSTenDLCPartnerCampaign.help_message"""
        self.model.help_message = "T" * 255
        assert self.model.get("help_message") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.help_message = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_optin_keywords(self):
        """Test SMSTenDLCPartnerCampaign.optin_keywords"""
        self.model.optin_keywords = "T" * 255
        assert self.model.get("optin_keywords") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.optin_keywords = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_optout_keywords(self):
        """Test SMSTenDLCPartnerCampaign.optout_keywords"""
        self.model.optout_keywords = "T" * 255
        assert self.model.get("optout_keywords") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.optout_keywords = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_help_keywords(self):
        """Test SMSTenDLCPartnerCampaign.help_keywords"""
        self.model.help_keywords = "T" * 255
        assert self.model.get("help_keywords") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.help_keywords = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_optin_message(self):
        """Test SMSTenDLCPartnerCampaign.optin_message"""
        self.model.optin_message = "T" * 255
        assert self.model.get("optin_message") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.optin_message = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_optout_message(self):
        """Test SMSTenDLCPartnerCampaign.optout_message"""
        self.model.optout_message = "T" * 255
        assert self.model.get("optout_message") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.optout_message = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_brand(self):
        """Test SMSTenDLCPartnerCampaign.brand"""
        object = SMSTenDLCPartnerCampaignBrand(phone="TEST_STRING", email="TEST_STRING")
        self.model.brand = object
        assert self.model.get("brand", object)

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.mutable_resource_model import MutableResourceModel
from freeclimb.model.queue_result_all_of import QueueResultAllOf
globals()['MutableResourceModel'] = MutableResourceModel
globals()['QueueResultAllOf'] = QueueResultAllOf

from freeclimb.model.queue_result import QueueResult  # noqa: E501

class TestQueueResult(unittest.TestCase):
    """QueueResult unit test stubs"""

    def setUp(self):
        self.model = QueueResult(
        )
    
    def test_uri(self):
        """Test QueueResult.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test QueueResult.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test QueueResult.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test QueueResult.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test_account_id(self):
        """Test QueueResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_queue_id(self):
        """Test QueueResult.queue_id"""
        self.model.queue_id = "TEST_STRING"
        assert self.model.get("queue_id") == "TEST_STRING"

    def test_alias(self):
        """Test QueueResult.alias"""
        self.model.alias = "TEST_STRING"
        assert self.model.get("alias") == "TEST_STRING"

    def test_max_size(self):
        """Test QueueResult.max_size"""
        self.model.max_size = 1
        assert self.model.get("max_size") == 1

    def test_current_size(self):
        """Test QueueResult.current_size"""
        self.model.current_size = 1
        assert self.model.get("current_size") == 1

    def test_average_queue_removal_time(self):
        """Test QueueResult.average_queue_removal_time"""
        self.model.average_queue_removal_time = 1
        assert self.model.get("average_queue_removal_time") == 1

    def test_subresource_uris(self):
        """Test QueueResult.subresource_uris"""
        testObject = {}
        self.model.subresource_uris = testObject
        assert self.model.get("subresource_uris") == testObject

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.mutable_resource_model import MutableResourceModel  # noqa: E501

class TestMutableResourceModel(unittest.TestCase):
    """MutableResourceModel unit test stubs"""

    def setUp(self):
        self.model = MutableResourceModel(
        )
    
    def test_uri(self):
        """Test MutableResourceModel.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test MutableResourceModel.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test MutableResourceModel.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test MutableResourceModel.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.capabilities import Capabilities
globals()['Capabilities'] = Capabilities

from freeclimb.model.incoming_number_result_all_of import IncomingNumberResultAllOf  # noqa: E501

class TestIncomingNumberResultAllOf(unittest.TestCase):
    """IncomingNumberResultAllOf unit test stubs"""

    def setUp(self):
        self.model = IncomingNumberResultAllOf(
        )
    
    def test_capabilities(self):
        """Test IncomingNumberResultAllOf.capabilities"""
        object = Capabilities(sms=False, voice=False, toll_free=False, ten_dlc=False, short_code=False)
        self.model.capabilities = object
        assert self.model.get("capabilities", object)

    def test_campaign_id(self):
        """Test IncomingNumberResultAllOf.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_phone_number_id(self):
        """Test IncomingNumberResultAllOf.phone_number_id"""
        self.model.phone_number_id = "TEST_STRING"
        assert self.model.get("phone_number_id") == "TEST_STRING"

    def test_account_id(self):
        """Test IncomingNumberResultAllOf.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_application_id(self):
        """Test IncomingNumberResultAllOf.application_id"""
        self.model.application_id = "TEST_STRING"
        assert self.model.get("application_id") == "TEST_STRING"

    def test_phone_number(self):
        """Test IncomingNumberResultAllOf.phone_number"""
        self.model.phone_number = "TEST_STRING"
        assert self.model.get("phone_number") == "TEST_STRING"

    def test_alias(self):
        """Test IncomingNumberResultAllOf.alias"""
        self.model.alias = "TEST_STRING"
        assert self.model.get("alias") == "TEST_STRING"

    def test_region(self):
        """Test IncomingNumberResultAllOf.region"""
        self.model.region = "TEST_STRING"
        assert self.model.get("region") == "TEST_STRING"

    def test_country(self):
        """Test IncomingNumberResultAllOf.country"""
        self.model.country = "TEST_STRING"
        assert self.model.get("country") == "TEST_STRING"

    def test_voice_enabled(self):
        """Test IncomingNumberResultAllOf.voice_enabled"""
        self.model.voice_enabled = False
        assert self.model.get("voice_enabled") == False

    def test_sms_enabled(self):
        """Test IncomingNumberResultAllOf.sms_enabled"""
        self.model.sms_enabled = False
        assert self.model.get("sms_enabled") == False

    def test_offnet(self):
        """Test IncomingNumberResultAllOf.offnet"""
        self.model.offnet = False
        assert self.model.get("offnet") == False

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.if_machine import IfMachine
globals()['IfMachine'] = IfMachine

from freeclimb.model.out_dial_all_of import OutDialAllOf  # noqa: E501

class TestOutDialAllOf(unittest.TestCase):
    """OutDialAllOf unit test stubs"""

    def setUp(self):
        self.model = OutDialAllOf(
            action_url="",
            call_connect_url="",
            calling_number="",
            destination="",
        )
    
    def test_action_url(self):
        """Test OutDialAllOf.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.get("action_url") == "TEST_STRING"

    def test_call_connect_url(self):
        """Test OutDialAllOf.call_connect_url"""
        self.model.call_connect_url = "TEST_STRING"
        assert self.model.get("call_connect_url") == "TEST_STRING"

    def test_calling_number(self):
        """Test OutDialAllOf.calling_number"""
        self.model.calling_number = "TEST_STRING"
        assert self.model.get("calling_number") == "TEST_STRING"

    def test_destination(self):
        """Test OutDialAllOf.destination"""
        self.model.destination = "TEST_STRING"
        assert self.model.get("destination") == "TEST_STRING"

    def test_if_machine(self):
        """Test OutDialAllOf.if_machine"""
        self.model.if_machine = IfMachine.REDIRECT
        assert self.model.get("if_machine") == IfMachine.REDIRECT
        self.model.if_machine = IfMachine.HANGUP
        assert self.model.get("if_machine") == IfMachine.HANGUP

    def test_if_machine_url(self):
        """Test OutDialAllOf.if_machine_url"""
        self.model.if_machine_url = "TEST_STRING"
        assert self.model.get("if_machine_url") == "TEST_STRING"

    def test_send_digits(self):
        """Test OutDialAllOf.send_digits"""
        self.model.send_digits = "TEST_STRING"
        assert self.model.get("send_digits") == "TEST_STRING"

    def test_status_callback_url(self):
        """Test OutDialAllOf.status_callback_url"""
        self.model.status_callback_url = "TEST_STRING"
        assert self.model.get("status_callback_url") == "TEST_STRING"

    def test_timeout(self):
        """Test OutDialAllOf.timeout"""
        self.model.timeout = 1
        assert self.model.get("timeout") == 1

    def test_privacy_mode(self):
        """Test OutDialAllOf.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.get("privacy_mode") == False

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from freeclimb.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from freeclimb.model.account_request import AccountRequest
from freeclimb.model.account_result import AccountResult
from freeclimb.model.account_result_all_of import AccountResultAllOf
from freeclimb.model.account_status import AccountStatus
from freeclimb.model.account_type import AccountType
from freeclimb.model.add_to_conference import AddToConference
from freeclimb.model.add_to_conference_all_of import AddToConferenceAllOf
from freeclimb.model.answered_by import AnsweredBy
from freeclimb.model.application_list import ApplicationList
from freeclimb.model.application_list_all_of import ApplicationListAllOf
from freeclimb.model.application_request import ApplicationRequest
from freeclimb.model.application_result import ApplicationResult
from freeclimb.model.application_result_all_of import ApplicationResultAllOf
from freeclimb.model.available_number import AvailableNumber
from freeclimb.model.available_number_list import AvailableNumberList
from freeclimb.model.available_number_list_all_of import AvailableNumberListAllOf
from freeclimb.model.buy_incoming_number_request import BuyIncomingNumberRequest
from freeclimb.model.call_direction import CallDirection
from freeclimb.model.call_list import CallList
from freeclimb.model.call_list_all_of import CallListAllOf
from freeclimb.model.call_result import CallResult
from freeclimb.model.call_result_all_of import CallResultAllOf
from freeclimb.model.call_status import CallStatus
from freeclimb.model.capabilities import Capabilities
from freeclimb.model.conference_list import ConferenceList
from freeclimb.model.conference_list_all_of import ConferenceListAllOf
from freeclimb.model.conference_participant_list import ConferenceParticipantList
from freeclimb.model.conference_participant_list_all_of import ConferenceParticipantListAllOf
from freeclimb.model.conference_participant_result import ConferenceParticipantResult
from freeclimb.model.conference_participant_result_all_of import ConferenceParticipantResultAllOf
from freeclimb.model.conference_result import ConferenceResult
from freeclimb.model.conference_result_all_of import ConferenceResultAllOf
from freeclimb.model.conference_status import ConferenceStatus
from freeclimb.model.create_conference import CreateConference
from freeclimb.model.create_conference_all_of import CreateConferenceAllOf
from freeclimb.model.create_conference_request import CreateConferenceRequest
from freeclimb.model.dequeue import Dequeue
from freeclimb.model.enqueue import Enqueue
from freeclimb.model.enqueue_all_of import EnqueueAllOf
from freeclimb.model.filter_logs_request import FilterLogsRequest
from freeclimb.model.get_digits import GetDigits
from freeclimb.model.get_digits_all_of import GetDigitsAllOf
from freeclimb.model.get_speech import GetSpeech
from freeclimb.model.get_speech_all_of import GetSpeechAllOf
from freeclimb.model.get_speech_reason import GetSpeechReason
from freeclimb.model.grammar_file_built_in import GrammarFileBuiltIn
from freeclimb.model.grammar_type import GrammarType
from freeclimb.model.hangup import Hangup
from freeclimb.model.hangup_all_of import HangupAllOf
from freeclimb.model.if_machine import IfMachine
from freeclimb.model.incoming_number_list import IncomingNumberList
from freeclimb.model.incoming_number_list_all_of import IncomingNumberListAllOf
from freeclimb.model.incoming_number_request import IncomingNumberRequest
from freeclimb.model.incoming_number_result import IncomingNumberResult
from freeclimb.model.incoming_number_result_all_of import IncomingNumberResultAllOf
from freeclimb.model.language import Language
from freeclimb.model.log_level import LogLevel
from freeclimb.model.log_list import LogList
from freeclimb.model.log_list_all_of import LogListAllOf
from freeclimb.model.log_result import LogResult
from freeclimb.model.machine_type import MachineType
from freeclimb.model.make_call_request import MakeCallRequest
from freeclimb.model.message_direction import MessageDirection
from freeclimb.model.message_request import MessageRequest
from freeclimb.model.message_request_all_of import MessageRequestAllOf
from freeclimb.model.message_result import MessageResult
from freeclimb.model.message_result_all_of import MessageResultAllOf
from freeclimb.model.message_status import MessageStatus
from freeclimb.model.messages_list import MessagesList
from freeclimb.model.messages_list_all_of import MessagesListAllOf
from freeclimb.model.mutable_resource_model import MutableResourceModel
from freeclimb.model.out_dial import OutDial
from freeclimb.model.out_dial_all_of import OutDialAllOf
from freeclimb.model.pagination_model import PaginationModel
from freeclimb.model.park import Park
from freeclimb.model.park_all_of import ParkAllOf
from freeclimb.model.pause import Pause
from freeclimb.model.pause_all_of import PauseAllOf
from freeclimb.model.percl_command import PerclCommand
from freeclimb.model.percl_script import PerclScript
from freeclimb.model.play import Play
from freeclimb.model.play_all_of import PlayAllOf
from freeclimb.model.play_beep import PlayBeep
from freeclimb.model.play_early_media import PlayEarlyMedia
from freeclimb.model.play_early_media_all_of import PlayEarlyMediaAllOf
from freeclimb.model.queue_list import QueueList
from freeclimb.model.queue_list_all_of import QueueListAllOf
from freeclimb.model.queue_member import QueueMember
from freeclimb.model.queue_member_list import QueueMemberList
from freeclimb.model.queue_member_list_all_of import QueueMemberListAllOf
from freeclimb.model.queue_request import QueueRequest
from freeclimb.model.queue_result import QueueResult
from freeclimb.model.queue_result_all_of import QueueResultAllOf
from freeclimb.model.queue_result_status import QueueResultStatus
from freeclimb.model.record_utterance import RecordUtterance
from freeclimb.model.record_utterance_all_of import RecordUtteranceAllOf
from freeclimb.model.record_utterance_term_reason import RecordUtteranceTermReason
from freeclimb.model.recording_list import RecordingList
from freeclimb.model.recording_list_all_of import RecordingListAllOf
from freeclimb.model.recording_result import RecordingResult
from freeclimb.model.recording_result_all_of import RecordingResultAllOf
from freeclimb.model.redirect import Redirect
from freeclimb.model.redirect_all_of import RedirectAllOf
from freeclimb.model.reject import Reject
from freeclimb.model.reject_all_of import RejectAllOf
from freeclimb.model.remove_from_conference import RemoveFromConference
from freeclimb.model.remove_from_conference_all_of import RemoveFromConferenceAllOf
from freeclimb.model.request_type import RequestType
from freeclimb.model.sms_ten_dlc_brand import SMSTenDLCBrand
from freeclimb.model.sms_ten_dlc_brands_list_result import SMSTenDLCBrandsListResult
from freeclimb.model.sms_ten_dlc_brands_list_result_all_of import SMSTenDLCBrandsListResultAllOf
from freeclimb.model.sms_ten_dlc_campaign import SMSTenDLCCampaign
from freeclimb.model.sms_ten_dlc_campaigns_list_result import SMSTenDLCCampaignsListResult
from freeclimb.model.sms_ten_dlc_campaigns_list_result_all_of import SMSTenDLCCampaignsListResultAllOf
from freeclimb.model.sms_ten_dlc_partner_campaign import SMSTenDLCPartnerCampaign
from freeclimb.model.sms_ten_dlc_partner_campaign_brand import SMSTenDLCPartnerCampaignBrand
from freeclimb.model.sms_ten_dlc_partner_campaigns_list_result import SMSTenDLCPartnerCampaignsListResult
from freeclimb.model.sms_ten_dlc_partner_campaigns_list_result_all_of import SMSTenDLCPartnerCampaignsListResultAllOf
from freeclimb.model.say import Say
from freeclimb.model.say_all_of import SayAllOf
from freeclimb.model.send_digits import SendDigits
from freeclimb.model.send_digits_all_of import SendDigitsAllOf
from freeclimb.model.set_listen import SetListen
from freeclimb.model.set_listen_all_of import SetListenAllOf
from freeclimb.model.set_talk import SetTalk
from freeclimb.model.set_talk_all_of import SetTalkAllOf
from freeclimb.model.sms import Sms
from freeclimb.model.sms_all_of import SmsAllOf
from freeclimb.model.start_record_call import StartRecordCall
from freeclimb.model.terminate_conference import TerminateConference
from freeclimb.model.terminate_conference_all_of import TerminateConferenceAllOf
from freeclimb.model.transcribe_utterance import TranscribeUtterance
from freeclimb.model.transcribe_utterance_record import TranscribeUtteranceRecord
from freeclimb.model.unpark import Unpark
from freeclimb.model.update_call_request import UpdateCallRequest
from freeclimb.model.update_call_request_status import UpdateCallRequestStatus
from freeclimb.model.update_conference_participant_request import UpdateConferenceParticipantRequest
from freeclimb.model.update_conference_request import UpdateConferenceRequest
from freeclimb.model.update_conference_request_status import UpdateConferenceRequestStatus



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.answered_by import AnsweredBy
from freeclimb.model.call_direction import CallDirection
from freeclimb.model.call_result_all_of import CallResultAllOf
from freeclimb.model.call_status import CallStatus
from freeclimb.model.mutable_resource_model import MutableResourceModel
globals()['AnsweredBy'] = AnsweredBy
globals()['CallDirection'] = CallDirection
globals()['CallResultAllOf'] = CallResultAllOf
globals()['CallStatus'] = CallStatus
globals()['MutableResourceModel'] = MutableResourceModel

from freeclimb.model.call_result import CallResult  # noqa: E501

class TestCallResult(unittest.TestCase):
    """CallResult unit test stubs"""

    def setUp(self):
        self.model = CallResult(
        )
    
    def test_uri(self):
        """Test CallResult.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test CallResult.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test CallResult.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test CallResult.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test_call_id(self):
        """Test CallResult.call_id"""
        self.model.call_id = "TEST_STRING"
        assert self.model.get("call_id") == "TEST_STRING"

    def test_parent_call_id(self):
        """Test CallResult.parent_call_id"""
        self.model.parent_call_id = "TEST_STRING"
        assert self.model.get("parent_call_id") == "TEST_STRING"

    def test_account_id(self):
        """Test CallResult.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test__from(self):
        """Test CallResult._from"""
        self.model._from = "TEST_STRING"
        assert self.model.get("_from") == "TEST_STRING"

    def test_to(self):
        """Test CallResult.to"""
        self.model.to = "TEST_STRING"
        assert self.model.get("to") == "TEST_STRING"

    def test_phone_number_id(self):
        """Test CallResult.phone_number_id"""
        self.model.phone_number_id = "TEST_STRING"
        assert self.model.get("phone_number_id") == "TEST_STRING"

    def test_call_status(self):
        """Test CallResult.call_status"""
        self.model.call_status = CallStatus.QUEUED
        assert self.model.get("call_status") == CallStatus.QUEUED
        self.model.call_status = CallStatus.RINGING
        assert self.model.get("call_status") == CallStatus.RINGING
        self.model.call_status = CallStatus.IN_PROGRESS
        assert self.model.get("call_status") == CallStatus.IN_PROGRESS
        self.model.call_status = CallStatus.CANCELED
        assert self.model.get("call_status") == CallStatus.CANCELED
        self.model.call_status = CallStatus.COMPLETED
        assert self.model.get("call_status") == CallStatus.COMPLETED
        self.model.call_status = CallStatus.FAILED
        assert self.model.get("call_status") == CallStatus.FAILED
        self.model.call_status = CallStatus.BUSY
        assert self.model.get("call_status") == CallStatus.BUSY
        self.model.call_status = CallStatus.NO_ANSWER
        assert self.model.get("call_status") == CallStatus.NO_ANSWER

    def test_start_time(self):
        """Test CallResult.start_time"""
        self.model.start_time = "TEST_STRING"
        assert self.model.get("start_time") == "TEST_STRING"

    def test_connect_time(self):
        """Test CallResult.connect_time"""
        self.model.connect_time = "TEST_STRING"
        assert self.model.get("connect_time") == "TEST_STRING"

    def test_end_time(self):
        """Test CallResult.end_time"""
        self.model.end_time = "TEST_STRING"
        assert self.model.get("end_time") == "TEST_STRING"

    def test_duration(self):
        """Test CallResult.duration"""
        self.model.duration = 1
        assert self.model.get("duration") == 1

    def test_connect_duration(self):
        """Test CallResult.connect_duration"""
        self.model.connect_duration = 1
        assert self.model.get("connect_duration") == 1

    def test_direction(self):
        """Test CallResult.direction"""
        self.model.direction = CallDirection.INBOUND
        assert self.model.get("direction") == CallDirection.INBOUND
        self.model.direction = CallDirection.OUTBOUND_API
        assert self.model.get("direction") == CallDirection.OUTBOUND_API
        self.model.direction = CallDirection.OUTBOUND_DIAL
        assert self.model.get("direction") == CallDirection.OUTBOUND_DIAL

    def test_answered_by(self):
        """Test CallResult.answered_by"""
        self.model.answered_by = AnsweredBy.HUMAN
        assert self.model.get("answered_by") == AnsweredBy.HUMAN
        self.model.answered_by = AnsweredBy.MACHINE
        assert self.model.get("answered_by") == AnsweredBy.MACHINE

    def test_subresource_uris(self):
        """Test CallResult.subresource_uris"""
        testObject = {}
        self.model.subresource_uris = testObject
        assert self.model.get("subresource_uris") == testObject

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.message_status import MessageStatus
globals()['MessageStatus'] = MessageStatus

from freeclimb.model.message_result_all_of import MessageResultAllOf  # noqa: E501

class TestMessageResultAllOf(unittest.TestCase):
    """MessageResultAllOf unit test stubs"""

    def setUp(self):
        self.model = MessageResultAllOf(
        )
    
    def test_account_id(self):
        """Test MessageResultAllOf.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_message_id(self):
        """Test MessageResultAllOf.message_id"""
        self.model.message_id = "TEST_STRING"
        assert self.model.get("message_id") == "TEST_STRING"

    def test_status(self):
        """Test MessageResultAllOf.status"""
        self.model.status = MessageStatus.NEW
        assert self.model.get("status") == MessageStatus.NEW
        self.model.status = MessageStatus.QUEUED
        assert self.model.get("status") == MessageStatus.QUEUED
        self.model.status = MessageStatus.REJECTED
        assert self.model.get("status") == MessageStatus.REJECTED
        self.model.status = MessageStatus.SENDING
        assert self.model.get("status") == MessageStatus.SENDING
        self.model.status = MessageStatus.SENT
        assert self.model.get("status") == MessageStatus.SENT
        self.model.status = MessageStatus.FAILED
        assert self.model.get("status") == MessageStatus.FAILED
        self.model.status = MessageStatus.RECEIVED
        assert self.model.get("status") == MessageStatus.RECEIVED
        self.model.status = MessageStatus.UNDELIVERED
        assert self.model.get("status") == MessageStatus.UNDELIVERED
        self.model.status = MessageStatus.EXPIRED
        assert self.model.get("status") == MessageStatus.EXPIRED
        self.model.status = MessageStatus.DELETED
        assert self.model.get("status") == MessageStatus.DELETED
        self.model.status = MessageStatus.UNKNOWN
        assert self.model.get("status") == MessageStatus.UNKNOWN

    def test__from(self):
        """Test MessageResultAllOf._from"""
        self.model._from = "TEST_STRING"
        assert self.model.get("_from") == "TEST_STRING"

    def test_to(self):
        """Test MessageResultAllOf.to"""
        self.model.to = "TEST_STRING"
        assert self.model.get("to") == "TEST_STRING"

    def test_text(self):
        """Test MessageResultAllOf.text"""
        self.model.text = "TEST_STRING"
        assert self.model.get("text") == "TEST_STRING"

    def test_direction(self):
        """Test MessageResultAllOf.direction"""
        self.model.direction = "TEST_STRING"
        assert self.model.get("direction") == "TEST_STRING"

    def test_notification_url(self):
        """Test MessageResultAllOf.notification_url"""
        self.model.notification_url = "TEST_STRING"
        assert self.model.get("notification_url") == "TEST_STRING"

    def test_brand_id(self):
        """Test MessageResultAllOf.brand_id"""
        self.model.brand_id = "TEST_STRING"
        assert self.model.get("brand_id") == "TEST_STRING"

    def test_campaign_id(self):
        """Test MessageResultAllOf.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_segment_count(self):
        """Test MessageResultAllOf.segment_count"""
        self.model.segment_count = float(1) 
        assert self.model.get("segment_count") == float(1)

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from freeclimb.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from freeclimb.exceptions import ApiAttributeError



from enum import Enum

# class syntax
class AccountStatus(str, Enum):
    CLOSED= "closed",
    SUSPENDED= "suspended",
    ACTIVE= "active",





"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.sms_ten_dlc_campaign import SMSTenDLCCampaign  # noqa: E501

class TestSMSTenDLCCampaign(unittest.TestCase):
    """SMSTenDLCCampaign unit test stubs"""

    def setUp(self):
        self.model = SMSTenDLCCampaign(
            campaign_id="",
            csp_id="",
            brand_id="",
            usecase="",
            sub_usecases=[],
            description="",
            mock=True,
        )
    
    def test_account_id(self):
        """Test SMSTenDLCCampaign.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_campaign_id(self):
        """Test SMSTenDLCCampaign.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_csp_id(self):
        """Test SMSTenDLCCampaign.csp_id"""
        self.model.csp_id = "TEST_STRING"
        assert self.model.get("csp_id") == "TEST_STRING"

    def test_reseller_id(self):
        """Test SMSTenDLCCampaign.reseller_id"""
        self.model.reseller_id = "T" * 8
        assert self.model.get("reseller_id") == "T" * 8
        
        with pytest.raises(Exception) as info:
            self.model.reseller_id = "T" * (8 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_status(self):
        """Test SMSTenDLCCampaign.status"""
        self.model.status = "ACTIVE"
        assert self.model.get("status") == "ACTIVE"
        self.model.status = "EXPIRED"
        assert self.model.get("status") == "EXPIRED"

    def test_status_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.status = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
    def test_create_date(self):
        """Test SMSTenDLCCampaign.create_date"""
        self.model.create_date = datetime.fromtimestamp(1691592436)
        assert self.model.get("create_date") == datetime.fromtimestamp(1691592436)

    def test_auto_renewal(self):
        """Test SMSTenDLCCampaign.auto_renewal"""
        self.model.auto_renewal = False
        assert self.model.get("auto_renewal") == False

    def test_billed_date(self):
        """Test SMSTenDLCCampaign.billed_date"""
        self.model.billed_date = datetime.fromtimestamp(1691592436)
        assert self.model.get("billed_date") == datetime.fromtimestamp(1691592436)

    def test_brand_id(self):
        """Test SMSTenDLCCampaign.brand_id"""
        self.model.brand_id = "T" * 8
        assert self.model.get("brand_id") == "T" * 8
        
        with pytest.raises(Exception) as info:
            self.model.brand_id = "T" * (8 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_usecase(self):
        """Test SMSTenDLCCampaign.usecase"""
        self.model.usecase = "T" * 20
        assert self.model.get("usecase") == "T" * 20
        
        with pytest.raises(Exception) as info:
            self.model.usecase = "T" * (20 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sub_usecases(self):
        """Test SMSTenDLCCampaign.sub_usecases"""
        testSet = [] 
        self.model.sub_usecases = testSet
        assert self.model.get("sub_usecases") == testSet

    def test_description(self):
        """Test SMSTenDLCCampaign.description"""
        self.model.description = "T" * 4096
        assert self.model.get("description") == "T" * 4096
        
        with pytest.raises(Exception) as info:
            self.model.description = "T" * (4096 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_embedded_link(self):
        """Test SMSTenDLCCampaign.embedded_link"""
        self.model.embedded_link = False
        assert self.model.get("embedded_link") == False

    def test_embedded_phone(self):
        """Test SMSTenDLCCampaign.embedded_phone"""
        self.model.embedded_phone = False
        assert self.model.get("embedded_phone") == False

    def test_affiliate_marketing(self):
        """Test SMSTenDLCCampaign.affiliate_marketing"""
        self.model.affiliate_marketing = False
        assert self.model.get("affiliate_marketing") == False

    def test_number_pool(self):
        """Test SMSTenDLCCampaign.number_pool"""
        self.model.number_pool = False
        assert self.model.get("number_pool") == False

    def test_age_gated(self):
        """Test SMSTenDLCCampaign.age_gated"""
        self.model.age_gated = False
        assert self.model.get("age_gated") == False

    def test_direct_lending(self):
        """Test SMSTenDLCCampaign.direct_lending"""
        self.model.direct_lending = False
        assert self.model.get("direct_lending") == False

    def test_subscriber_optin(self):
        """Test SMSTenDLCCampaign.subscriber_optin"""
        self.model.subscriber_optin = False
        assert self.model.get("subscriber_optin") == False

    def test_subscriber_optout(self):
        """Test SMSTenDLCCampaign.subscriber_optout"""
        self.model.subscriber_optout = False
        assert self.model.get("subscriber_optout") == False

    def test_subscriber_help(self):
        """Test SMSTenDLCCampaign.subscriber_help"""
        self.model.subscriber_help = False
        assert self.model.get("subscriber_help") == False

    def test_sample1(self):
        """Test SMSTenDLCCampaign.sample1"""
        self.model.sample1 = "T" * 1024
        assert self.model.get("sample1") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample1 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample2(self):
        """Test SMSTenDLCCampaign.sample2"""
        self.model.sample2 = "T" * 1024
        assert self.model.get("sample2") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample2 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample3(self):
        """Test SMSTenDLCCampaign.sample3"""
        self.model.sample3 = "T" * 1024
        assert self.model.get("sample3") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample3 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample4(self):
        """Test SMSTenDLCCampaign.sample4"""
        self.model.sample4 = "T" * 1024
        assert self.model.get("sample4") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample4 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_sample5(self):
        """Test SMSTenDLCCampaign.sample5"""
        self.model.sample5 = "T" * 1024
        assert self.model.get("sample5") == "T" * 1024
        
        with pytest.raises(Exception) as info:
            self.model.sample5 = "T" * (1024 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_message_flow(self):
        """Test SMSTenDLCCampaign.message_flow"""
        self.model.message_flow = "T" * 2048
        assert self.model.get("message_flow") == "T" * 2048
        
        with pytest.raises(Exception) as info:
            self.model.message_flow = "T" * (2048 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_help_message(self):
        """Test SMSTenDLCCampaign.help_message"""
        self.model.help_message = "T" * 255
        assert self.model.get("help_message") == "T" * 255
        
        with pytest.raises(Exception) as info:
            self.model.help_message = "T" * (255 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_reference_id(self):
        """Test SMSTenDLCCampaign.reference_id"""
        self.model.reference_id = "T" * 50
        assert self.model.get("reference_id") == "T" * 50
        
        with pytest.raises(Exception) as info:
            self.model.reference_id = "T" * (50 + 1)
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__

    def test_mock(self):
        """Test SMSTenDLCCampaign.mock"""
        self.model.mock = False
        assert self.model.get("mock") == False

    def test_next_renewal_or_expiration_date(self):
        """Test SMSTenDLCCampaign.next_renewal_or_expiration_date"""
        self.model.next_renewal_or_expiration_date = date.fromtimestamp(1691592436)
        assert self.model.get("next_renewal_or_expiration_date") == date.fromtimestamp(1691592436) 

if __name__ == '__main__':
    unittest.main()



"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.message_request_all_of import MessageRequestAllOf
from freeclimb.model.mutable_resource_model import MutableResourceModel
globals()['MessageRequestAllOf'] = MessageRequestAllOf
globals()['MutableResourceModel'] = MutableResourceModel

from freeclimb.model.message_request import MessageRequest  # noqa: E501

class TestMessageRequest(unittest.TestCase):
    """MessageRequest unit test stubs"""

    def setUp(self):
        self.model = MessageRequest(
            _from="",
            to="",
            text="",
        )
    
    def test_uri(self):
        """Test MessageRequest.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test MessageRequest.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test MessageRequest.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test MessageRequest.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test__from(self):
        """Test MessageRequest._from"""
        self.model._from = "TEST_STRING"
        assert self.model.get("_from") == "TEST_STRING"

    def test_to(self):
        """Test MessageRequest.to"""
        self.model.to = "TEST_STRING"
        assert self.model.get("to") == "TEST_STRING"

    def test_text(self):
        """Test MessageRequest.text"""
        self.model.text = "TEST_STRING"
        assert self.model.get("text") == "TEST_STRING"

    def test_notification_url(self):
        """Test MessageRequest.notification_url"""
        self.model.notification_url = "TEST_STRING"
        assert self.model.get("notification_url") == "TEST_STRING"

    def test_account_id(self):
        """Test MessageRequest.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

if __name__ == '__main__':
    unittest.main()
